/****************************************************************************
** Meta object code from reading C++ file 'worksheetentry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.07.80/src/worksheetentry.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'worksheetentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14WorksheetEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto WorksheetEntry::qt_create_metaobjectdata<qt_meta_tag_ZN14WorksheetEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorksheetEntry",
        "aboutToBeDeleted",
        "",
        "evaluate",
        "WorksheetEntry::EvaluationOption",
        "evalOp",
        "evaluateCurrentItem",
        "updateEntry",
        "updateAfterSettingsChanges",
        "insertCommandEntry",
        "insertTextEntry",
        "insertMarkdownEntry",
        "insertLatexEntry",
        "insertImageEntry",
        "insertPageBreakEntry",
        "insertHorizontalRuleEntry",
        "insertHierarchyEntry",
        "insertCommandEntryBefore",
        "insertTextEntryBefore",
        "insertMarkdownEntryBefore",
        "insertLatexEntryBefore",
        "insertImageEntryBefore",
        "insertPageBreakEntryBefore",
        "insertHorizontalRuleEntryBefore",
        "insertHierarchyEntryBefore",
        "convertToCommandEntry",
        "convertToTextEntry",
        "convertToMarkdownEntry",
        "convertToLatexEntry",
        "convertToImageEntry",
        "converToPageBreakEntry",
        "convertToHorizontalRuleEntry",
        "convertToHierarchyEntry",
        "sizeAnimated",
        "startRemoving",
        "warn",
        "stopRemoving",
        "moveToPreviousEntry",
        "pos",
        "x",
        "moveToNextEntry",
        "recalculateSize",
        "animateSizeChange",
        "fadeInItem",
        "QGraphicsObject*",
        "item",
        "const char*",
        "slot",
        "fadeOutItem",
        "endAnimation",
        "showActionBar",
        "hideActionBar",
        "startDrag",
        "QPointF",
        "grabPos",
        "moveToNext",
        "updateLayout",
        "moveToPrevious",
        "remove",
        "deleteActionBar",
        "deleteActionBarAnimation",
        "size",
        "QSizeF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToBeDeleted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool(WorksheetEntry::EvaluationOption)>(3, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'evaluateCurrentItem'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'updateEntry'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAfterSettingsChanges'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertCommandEntry'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTextEntry'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertMarkdownEntry'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertLatexEntry'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertImageEntry'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertPageBreakEntry'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertHorizontalRuleEntry'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertHierarchyEntry'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertCommandEntryBefore'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTextEntryBefore'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertMarkdownEntryBefore'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertLatexEntryBefore'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertImageEntryBefore'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertPageBreakEntryBefore'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertHorizontalRuleEntryBefore'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertHierarchyEntryBefore'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToCommandEntry'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToTextEntry'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToMarkdownEntry'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToLatexEntry'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToImageEntry'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'converToPageBreakEntry'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToHorizontalRuleEntry'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'convertToHierarchyEntry'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sizeAnimated'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startRemoving'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'startRemoving'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'stopRemoving'
        QtMocHelpers::SlotData<bool()>(36, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'moveToPreviousEntry'
        QtMocHelpers::SlotData<void(int, qreal)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 }, { QMetaType::QReal, 39 },
        }}),
        // Slot 'moveToPreviousEntry'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'moveToPreviousEntry'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveToNextEntry'
        QtMocHelpers::SlotData<void(int, qreal)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 }, { QMetaType::QReal, 39 },
        }}),
        // Slot 'moveToNextEntry'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'moveToNextEntry'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'recalculateSize'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'animateSizeChange'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fadeInItem'
        QtMocHelpers::SlotData<void(QGraphicsObject *, const char *)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Slot 'fadeInItem'
        QtMocHelpers::SlotData<void(QGraphicsObject *)>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'fadeInItem'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'fadeOutItem'
        QtMocHelpers::SlotData<void(QGraphicsObject *, const char *)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Slot 'fadeOutItem'
        QtMocHelpers::SlotData<void(QGraphicsObject *)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'fadeOutItem'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'endAnimation'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showActionBar'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideActionBar'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startDrag'
        QtMocHelpers::SlotData<void(QPointF)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'startDrag'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveToNext'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 56 },
        }}),
        // Slot 'moveToNext'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveToPrevious'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 56 },
        }}),
        // Slot 'moveToPrevious'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'deleteActionBar'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'deleteActionBarAnimation'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WorksheetEntry, qt_meta_tag_ZN14WorksheetEntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorksheetEntry::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WorksheetEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WorksheetEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14WorksheetEntryE_t>.metaTypes,
    nullptr
} };

void WorksheetEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorksheetEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToBeDeleted(); break;
        case 1: { bool _r = _t->evaluate((*reinterpret_cast<std::add_pointer_t<WorksheetEntry::EvaluationOption>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->evaluate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->evaluateCurrentItem();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->updateEntry(); break;
        case 5: _t->updateAfterSettingsChanges(); break;
        case 6: _t->insertCommandEntry(); break;
        case 7: _t->insertTextEntry(); break;
        case 8: _t->insertMarkdownEntry(); break;
        case 9: _t->insertLatexEntry(); break;
        case 10: _t->insertImageEntry(); break;
        case 11: _t->insertPageBreakEntry(); break;
        case 12: _t->insertHorizontalRuleEntry(); break;
        case 13: _t->insertHierarchyEntry(); break;
        case 14: _t->insertCommandEntryBefore(); break;
        case 15: _t->insertTextEntryBefore(); break;
        case 16: _t->insertMarkdownEntryBefore(); break;
        case 17: _t->insertLatexEntryBefore(); break;
        case 18: _t->insertImageEntryBefore(); break;
        case 19: _t->insertPageBreakEntryBefore(); break;
        case 20: _t->insertHorizontalRuleEntryBefore(); break;
        case 21: _t->insertHierarchyEntryBefore(); break;
        case 22: _t->convertToCommandEntry(); break;
        case 23: _t->convertToTextEntry(); break;
        case 24: _t->convertToMarkdownEntry(); break;
        case 25: _t->convertToLatexEntry(); break;
        case 26: _t->convertToImageEntry(); break;
        case 27: _t->converToPageBreakEntry(); break;
        case 28: _t->convertToHorizontalRuleEntry(); break;
        case 29: _t->convertToHierarchyEntry(); break;
        case 30: _t->sizeAnimated(); break;
        case 31: _t->startRemoving((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->startRemoving(); break;
        case 33: { bool _r = _t->stopRemoving();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->moveToPreviousEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 35: _t->moveToPreviousEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->moveToPreviousEntry(); break;
        case 37: _t->moveToNextEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 38: _t->moveToNextEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->moveToNextEntry(); break;
        case 40: _t->recalculateSize(); break;
        case 41: _t->animateSizeChange(); break;
        case 42: _t->fadeInItem((*reinterpret_cast<std::add_pointer_t<QGraphicsObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2]))); break;
        case 43: _t->fadeInItem((*reinterpret_cast<std::add_pointer_t<QGraphicsObject*>>(_a[1]))); break;
        case 44: _t->fadeInItem(); break;
        case 45: _t->fadeOutItem((*reinterpret_cast<std::add_pointer_t<QGraphicsObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2]))); break;
        case 46: _t->fadeOutItem((*reinterpret_cast<std::add_pointer_t<QGraphicsObject*>>(_a[1]))); break;
        case 47: _t->fadeOutItem(); break;
        case 48: _t->endAnimation(); break;
        case 49: _t->showActionBar(); break;
        case 50: _t->hideActionBar(); break;
        case 51: _t->startDrag((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 52: _t->startDrag(); break;
        case 53: _t->moveToNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 54: _t->moveToNext(); break;
        case 55: _t->moveToPrevious((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 56: _t->moveToPrevious(); break;
        case 57: _t->remove(); break;
        case 58: _t->deleteActionBar(); break;
        case 59: _t->deleteActionBarAnimation(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsObject* >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsObject* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsObject* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsObject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorksheetEntry::*)()>(_a, &WorksheetEntry::aboutToBeDeleted, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSizeF*>(_v) = _t->size(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSize(*reinterpret_cast<QSizeF*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WorksheetEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorksheetEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WorksheetEntryE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsObject::qt_metacast(_clname);
}

int WorksheetEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void WorksheetEntry::aboutToBeDeleted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
