/********************************************************************************
** Form generated from reading UI file 'directivecontainer.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIRECTIVECONTAINER_H
#define UI_DIRECTIVECONTAINER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_directiveContainer
{
public:

    void setupUi(QGroupBox *directiveContainer)
    {
        if (directiveContainer->objectName().isEmpty())
            directiveContainer->setObjectName("directiveContainer");
        directiveContainer->resize(400, 300);
        directiveContainer->setCheckable(true);

        retranslateUi(directiveContainer);

        QMetaObject::connectSlotsByName(directiveContainer);
    } // setupUi

    void retranslateUi(QGroupBox *directiveContainer)
    {
        directiveContainer->setTitle(tr2i18n("Option active", nullptr));
    } // retranslateUi

};

namespace Ui {
    class directiveContainer: public Ui_directiveContainer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIRECTIVECONTAINER_H

