/********************************************************************************
** Form generated from reading UI file 'qthelpconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QTHELPCONFIG_H
#define UI_QTHELPCONFIG_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_QtHelpConfigUI
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *qchTable;
    QHBoxLayout *tableCtrlLayout;
    QPushButton *addButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *QtHelpConfigUI)
    {
        if (QtHelpConfigUI->objectName().isEmpty())
            QtHelpConfigUI->setObjectName("QtHelpConfigUI");
        QtHelpConfigUI->resize(588, 389);
        QtHelpConfigUI->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        verticalLayout = new QVBoxLayout(QtHelpConfigUI);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(QtHelpConfigUI);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label);

        qchTable = new QTreeWidget(QtHelpConfigUI);
        qchTable->headerItem()->setText(4, QString());
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(3, QString::fromUtf8("Ghns"));
        __qtreewidgetitem->setText(2, QString::fromUtf8("IconName"));
        qchTable->setHeaderItem(__qtreewidgetitem);
        qchTable->setObjectName("qchTable");
        qchTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        qchTable->setRootIsDecorated(false);
        qchTable->setWordWrap(false);
        qchTable->setColumnCount(5);
        qchTable->setProperty("showGrid", QVariant(false));
        qchTable->header()->setVisible(true);

        verticalLayout->addWidget(qchTable);

        tableCtrlLayout = new QHBoxLayout();
        tableCtrlLayout->setObjectName("tableCtrlLayout");
        addButton = new QPushButton(QtHelpConfigUI);
        addButton->setObjectName("addButton");

        tableCtrlLayout->addWidget(addButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        tableCtrlLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(tableCtrlLayout);


        retranslateUi(QtHelpConfigUI);

        QMetaObject::connectSlotsByName(QtHelpConfigUI);
    } // setupUi

    void retranslateUi(QWidget *QtHelpConfigUI)
    {
        label->setText(tr2i18n("Install Additional Documentation Files", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = qchTable->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Path", "@title:column"));
        ___qtreewidgetitem->setText(0, tr2i18n("Name", "@title:column"));
        addButton->setText(tr2i18n("Add", "@action:button"));
        (void)QtHelpConfigUI;
    } // retranslateUi

};

namespace Ui {
    class QtHelpConfigUI: public Ui_QtHelpConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QTHELPCONFIG_H

