/****************************************************************************
** Meta object code from reading C++ file 'cantor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.07.80/src/cantor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cantor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11CantorShellE_t {};
} // unnamed namespace

template <> constexpr inline auto CantorShell::qt_create_metaobjectdata<qt_meta_tag_ZN11CantorShellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CantorShell",
        "showHelp",
        "",
        "hierarchyChanged",
        "QList<int>",
        "hierarhyEntryNameChange",
        "requestScrollToHierarchyEntry",
        "settingsChanges",
        "requestDocumentation",
        "addWorksheet",
        "load",
        "QUrl",
        "fileNew",
        "fileOpen",
        "onWorksheetSave",
        "optionsConfigureKeys",
        "activateWorksheet",
        "index",
        "setTabCaption",
        "QIcon",
        "updateBackendForPart",
        "closeTab",
        "showSettings",
        "openExample",
        "initPanels",
        "updatePanel",
        "updateNewSubmenu",
        "pluginVisibilityRequested",
        "pluginCommandRunRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showHelp'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'hierarchyChanged'
        QtMocHelpers::SignalData<void(QStringList, QStringList, QList<int>)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::QStringList, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'hierarhyEntryNameChange'
        QtMocHelpers::SignalData<void(QString, QString, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'requestScrollToHierarchyEntry'
        QtMocHelpers::SignalData<void(QString)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'settingsChanges'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestDocumentation'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'addWorksheet'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'fileNew'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWorksheetSave'
        QtMocHelpers::SlotData<void(const QUrl &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'optionsConfigureKeys'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateWorksheet'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setTabCaption'
        QtMocHelpers::SlotData<void(const QString &, const QIcon &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 19, 2 },
        }}),
        // Slot 'updateBackendForPart'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'showSettings'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openExample'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initPanels'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePanel'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateNewSubmenu'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pluginVisibilityRequested'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pluginCommandRunRequested'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CantorShell, qt_meta_tag_ZN11CantorShellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CantorShell::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::MainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CantorShellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CantorShellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11CantorShellE_t>.metaTypes,
    nullptr
} };

void CantorShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CantorShell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showHelp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->hierarchyChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 2: _t->hierarhyEntryNameChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->requestScrollToHierarchyEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->settingsChanges(); break;
        case 5: _t->requestDocumentation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->addWorksheet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->load((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->fileNew(); break;
        case 9: _t->fileOpen(); break;
        case 10: _t->onWorksheetSave((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->optionsConfigureKeys(); break;
        case 12: _t->activateWorksheet((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->setTabCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[2]))); break;
        case 14: _t->updateBackendForPart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->closeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->closeTab(); break;
        case 17: _t->showSettings(); break;
        case 18: _t->openExample(); break;
        case 19: _t->initPanels(); break;
        case 20: _t->updatePanel(); break;
        case 21: _t->updateNewSubmenu(); break;
        case 22: _t->pluginVisibilityRequested(); break;
        case 23: _t->pluginCommandRunRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CantorShell::*)(QString )>(_a, &CantorShell::showHelp, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorShell::*)(QStringList , QStringList , QList<int> )>(_a, &CantorShell::hierarchyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorShell::*)(QString , QString , int )>(_a, &CantorShell::hierarhyEntryNameChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorShell::*)(QString )>(_a, &CantorShell::requestScrollToHierarchyEntry, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorShell::*)()>(_a, &CantorShell::settingsChanges, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CantorShell::*)(const QString & )>(_a, &CantorShell::requestDocumentation, 5))
            return;
    }
}

const QMetaObject *CantorShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CantorShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CantorShellE_t>.strings))
        return static_cast<void*>(this);
    return KParts::MainWindow::qt_metacast(_clname);
}

int CantorShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void CantorShell::showHelp(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CantorShell::hierarchyChanged(QStringList _t1, QStringList _t2, QList<int> _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void CantorShell::hierarhyEntryNameChange(QString _t1, QString _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void CantorShell::requestScrollToHierarchyEntry(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CantorShell::settingsChanges()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CantorShell::requestDocumentation(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
