/********************************************************************************
** Form generated from reading UI file 'eigenvectorsdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EIGENVECTORSDLG_H
#define UI_EIGENVECTORSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_EigenVectorsAssistantBase
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KLineEdit *matrix;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *EigenVectorsAssistantBase)
    {
        if (EigenVectorsAssistantBase->objectName().isEmpty())
            EigenVectorsAssistantBase->setObjectName("EigenVectorsAssistantBase");
        EigenVectorsAssistantBase->resize(302, 98);
        gridLayout = new QGridLayout(EigenVectorsAssistantBase);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(EigenVectorsAssistantBase);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        matrix = new KLineEdit(EigenVectorsAssistantBase);
        matrix->setObjectName("matrix");

        gridLayout->addWidget(matrix, 1, 1, 1, 1);

        buttonBox = new QDialogButtonBox(EigenVectorsAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 1, 1, 1);


        retranslateUi(EigenVectorsAssistantBase);

        QMetaObject::connectSlotsByName(EigenVectorsAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *EigenVectorsAssistantBase)
    {
        label->setText(tr2i18n("Matrix:", nullptr));
        (void)EigenVectorsAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class EigenVectorsAssistantBase: public Ui_EigenVectorsAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EIGENVECTORSDLG_H

