/********************************************************************************
** Form generated from reading UI file 'solvedlg.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SOLVEDLG_H
#define UI_SOLVEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_SolveAssistantBase
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QPlainTextEdit *equations;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    KLineEdit *variables;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *SolveAssistantBase)
    {
        if (SolveAssistantBase->objectName().isEmpty())
            SolveAssistantBase->setObjectName("SolveAssistantBase");
        SolveAssistantBase->resize(400, 300);
        verticalLayout = new QVBoxLayout(SolveAssistantBase);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SolveAssistantBase);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        equations = new QPlainTextEdit(SolveAssistantBase);
        equations->setObjectName("equations");

        horizontalLayout->addWidget(equations);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(SolveAssistantBase);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        variables = new KLineEdit(SolveAssistantBase);
        variables->setObjectName("variables");

        horizontalLayout_2->addWidget(variables);


        verticalLayout->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(SolveAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SolveAssistantBase);

        QMetaObject::connectSlotsByName(SolveAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *SolveAssistantBase)
    {
        label->setText(tr2i18n("Equations:", nullptr));
        label_2->setText(tr2i18n("Variables:", nullptr));
        (void)SolveAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class SolveAssistantBase: public Ui_SolveAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SOLVEDLG_H

