/****************************************************************************
** Meta object code from reading C++ file 'worksheettexteditoritem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.07.80/src/worksheettexteditoritem.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'worksheettexteditoritem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23WorksheetTextEditorItemE_t {};
} // unnamed namespace

template <> constexpr inline auto WorksheetTextEditorItem::qt_create_metaobjectdata<qt_meta_tag_ZN23WorksheetTextEditorItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorksheetTextEditorItem",
        "moveToPrevious",
        "",
        "pos",
        "xCoord",
        "moveToNext",
        "cursorPositionChanged",
        "KTextEditor::Cursor",
        "receivedFocus",
        "WorksheetTextEditorItem*",
        "item",
        "tabPressed",
        "backtabPressed",
        "applyCompletion",
        "doubleClick",
        "execute",
        "deleteEntry",
        "sizeChanged",
        "menuCreated",
        "QMenu*",
        "QPointF",
        "drag",
        "startPos",
        "currentPos",
        "undoAvailable",
        "redoAvailable",
        "cutAvailable",
        "copyAvailable",
        "pasteAvailable",
        "textContentModified",
        "modificationStatysChanged",
        "isModified",
        "editorSelectionChanged",
        "undo",
        "redo",
        "cut",
        "copy",
        "paste",
        "selectionChanged",
        "testSize",
        "clipboardChanged",
        "showCustomCompleter",
        "QList<CantorCompletionModel::CompletionItem>",
        "onCompleterItemSelected",
        "hideCompleterAndResetFocus",
        "DoubleClickEventBehaviour",
        "Simple",
        "ImageReplacement",
        "EditorMode",
        "ReadOnly",
        "Editable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'moveToPrevious'
        QtMocHelpers::SignalData<void(int, qreal)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QReal, 4 },
        }}),
        // Signal 'moveToNext'
        QtMocHelpers::SignalData<void(int, qreal)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QReal, 4 },
        }}),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void(const KTextEditor::Cursor &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 3 },
        }}),
        // Signal 'receivedFocus'
        QtMocHelpers::SignalData<void(WorksheetTextEditorItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'tabPressed'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backtabPressed'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applyCompletion'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClick'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'execute'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteEntry'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'menuCreated'
        QtMocHelpers::SignalData<void(QMenu *, QPointF)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 }, { 0x80000000 | 20, 2 },
        }}),
        // Signal 'drag'
        QtMocHelpers::SignalData<void(const QPointF &, const QPointF &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 22 }, { 0x80000000 | 20, 23 },
        }}),
        // Signal 'undoAvailable'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'redoAvailable'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'cutAvailable'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'pasteAvailable'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'textContentModified'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modificationStatysChanged'
        QtMocHelpers::SignalData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'editorSelectionChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'testSize'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clipboardChanged'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showCustomCompleter'
        QtMocHelpers::SlotData<void(const QList<CantorCompletionModel::CompletionItem> &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 },
        }}),
        // Slot 'onCompleterItemSelected'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'hideCompleterAndResetFocus'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DoubleClickEventBehaviour'
        QtMocHelpers::EnumData<enum DoubleClickEventBehaviour>(45, 45, QMC::EnumFlags{}).add({
            {   46, DoubleClickEventBehaviour::Simple },
            {   47, DoubleClickEventBehaviour::ImageReplacement },
        }),
        // enum 'EditorMode'
        QtMocHelpers::EnumData<enum EditorMode>(48, 48, QMC::EnumFlags{}).add({
            {   49, EditorMode::ReadOnly },
            {   50, EditorMode::Editable },
        }),
    };
    return QtMocHelpers::metaObjectData<WorksheetTextEditorItem, qt_meta_tag_ZN23WorksheetTextEditorItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorksheetTextEditorItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsProxyWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23WorksheetTextEditorItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23WorksheetTextEditorItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23WorksheetTextEditorItemE_t>.metaTypes,
    nullptr
} };

void WorksheetTextEditorItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorksheetTextEditorItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveToPrevious((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 1: _t->moveToNext((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 2: _t->cursorPositionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1]))); break;
        case 3: _t->receivedFocus((*reinterpret_cast<std::add_pointer_t<WorksheetTextEditorItem*>>(_a[1]))); break;
        case 4: _t->tabPressed(); break;
        case 5: _t->backtabPressed(); break;
        case 6: _t->applyCompletion(); break;
        case 7: _t->doubleClick(); break;
        case 8: _t->execute(); break;
        case 9: _t->deleteEntry(); break;
        case 10: _t->sizeChanged(); break;
        case 11: _t->menuCreated((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 12: _t->drag((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 13: _t->undoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->redoAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->cutAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->pasteAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->textContentModified(); break;
        case 19: _t->modificationStatysChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->editorSelectionChanged(); break;
        case 21: _t->undo(); break;
        case 22: _t->redo(); break;
        case 23: _t->cut(); break;
        case 24: _t->copy(); break;
        case 25: _t->paste(); break;
        case 26: _t->selectionChanged(); break;
        case 27: _t->testSize(); break;
        case 28: _t->clipboardChanged(); break;
        case 29: _t->showCustomCompleter((*reinterpret_cast<std::add_pointer_t<QList<CantorCompletionModel::CompletionItem>>>(_a[1]))); break;
        case 30: _t->onCompleterItemSelected(); break;
        case 31: _t->hideCompleterAndResetFocus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WorksheetTextEditorItem* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(int , qreal )>(_a, &WorksheetTextEditorItem::moveToPrevious, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(int , qreal )>(_a, &WorksheetTextEditorItem::moveToNext, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(const KTextEditor::Cursor & )>(_a, &WorksheetTextEditorItem::cursorPositionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(WorksheetTextEditorItem * )>(_a, &WorksheetTextEditorItem::receivedFocus, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::tabPressed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::backtabPressed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::applyCompletion, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::doubleClick, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::execute, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::deleteEntry, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::sizeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(QMenu * , QPointF )>(_a, &WorksheetTextEditorItem::menuCreated, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(const QPointF & , const QPointF & )>(_a, &WorksheetTextEditorItem::drag, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(bool )>(_a, &WorksheetTextEditorItem::undoAvailable, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(bool )>(_a, &WorksheetTextEditorItem::redoAvailable, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(bool )>(_a, &WorksheetTextEditorItem::cutAvailable, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(bool )>(_a, &WorksheetTextEditorItem::copyAvailable, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(bool )>(_a, &WorksheetTextEditorItem::pasteAvailable, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::textContentModified, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)(bool )>(_a, &WorksheetTextEditorItem::modificationStatysChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorksheetTextEditorItem::*)()>(_a, &WorksheetTextEditorItem::editorSelectionChanged, 20))
            return;
    }
}

const QMetaObject *WorksheetTextEditorItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorksheetTextEditorItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23WorksheetTextEditorItemE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsProxyWidget::qt_metacast(_clname);
}

int WorksheetTextEditorItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsProxyWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void WorksheetTextEditorItem::moveToPrevious(int _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void WorksheetTextEditorItem::moveToNext(int _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void WorksheetTextEditorItem::cursorPositionChanged(const KTextEditor::Cursor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WorksheetTextEditorItem::receivedFocus(WorksheetTextEditorItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WorksheetTextEditorItem::tabPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void WorksheetTextEditorItem::backtabPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void WorksheetTextEditorItem::applyCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void WorksheetTextEditorItem::doubleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void WorksheetTextEditorItem::execute()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void WorksheetTextEditorItem::deleteEntry()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void WorksheetTextEditorItem::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void WorksheetTextEditorItem::menuCreated(QMenu * _t1, QPointF _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void WorksheetTextEditorItem::drag(const QPointF & _t1, const QPointF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void WorksheetTextEditorItem::undoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void WorksheetTextEditorItem::redoAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void WorksheetTextEditorItem::cutAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void WorksheetTextEditorItem::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void WorksheetTextEditorItem::pasteAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void WorksheetTextEditorItem::textContentModified()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void WorksheetTextEditorItem::modificationStatysChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void WorksheetTextEditorItem::editorSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
