// This file is generated by kconfig_compiler_kf6 from kalgebrabackend.kcfg.
// All changes you do to this file will be lost.
#ifndef KALGEBRASETTINGS_H
#define KALGEBRASETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KAlgebraSettings : public KConfigSkeleton
{
  public:

    static KAlgebraSettings *self();
    ~KAlgebraSettings() override;

    /**
      Get List of scripts to autorun at the beginning of session
    */
    static
    QStringList autorunScripts()
    {
      return self()->mAutorunScripts;
    }

    /**
      Is List of scripts to autorun at the beginning of session Immutable
    */
    static
    bool isAutorunScriptsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autorunScripts" ) );
    }

  protected:
    KAlgebraSettings();
    friend class KAlgebraSettingsHelper;


    // KAlgebraBackend
    QStringList mAutorunScripts;
};

#endif

