/********************************************************************************
** Form generated from reading UI file 'formating.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FORMATING_H
#define UI_FORMATING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsFormatting
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *ChapterTab;
    QFormLayout *verticalLayout;
    QLabel *lChapterFontFamily;
    QFontComboBox *kcfg_ChapterFontFamily;
    QLabel *lChapterFontSize;
    QSpinBox *kcfg_ChapterFontSize;
    QCheckBox *kcfg_ChapterFontBold;
    QCheckBox *kcfg_ChapterFontItalic;
    QWidget *SubchapterTab;
    QFormLayout *verticalLayout4;
    QLabel *lSubchapterFontFamily;
    QFontComboBox *kcfg_SubchapterFontFamily;
    QLabel *lSubchapterFontSize;
    QSpinBox *kcfg_SubchapterFontSize;
    QCheckBox *kcfg_SubchapterFontBold;
    QCheckBox *kcfg_SubchapterFontItalic;
    QWidget *SectionTab;
    QFormLayout *verticalLayout3;
    QLabel *lSectionFontFamily;
    QFontComboBox *kcfg_SectionFontFamily;
    QLabel *lSectionFontSize;
    QSpinBox *kcfg_SectionFontSize;
    QCheckBox *kcfg_SectionFontBold;
    QCheckBox *kcfg_SectionFontItalic;
    QWidget *SubsectionTab;
    QFormLayout *verticalLayout6;
    QLabel *lSubsectionFontFamily;
    QFontComboBox *kcfg_SubsectionFontFamily;
    QLabel *lSubsetctionFontSize;
    QSpinBox *kcfg_SubsectionFontSize;
    QCheckBox *kcfg_SubsectionFontBold;
    QCheckBox *kcfg_SubsectionFontItalic;
    QWidget *ParagraphTab;
    QFormLayout *verticalLayout2;
    QLabel *lParagraphFontFamily;
    QFontComboBox *kcfg_ParagraphFontFamily;
    QLabel *lParagrapshFontSize;
    QSpinBox *kcfg_ParagraphFontSize;
    QCheckBox *kcfg_ParagraphFontBold;
    QCheckBox *kcfg_ParagraphFontItalic;
    QWidget *SubparagraphTab;
    QFormLayout *verticalLayout5;
    QLabel *lSubparagraphFontFamily;
    QFontComboBox *kcfg_SubparagraphFontFamily;
    QLabel *lSubparagraphFontSize;
    QSpinBox *kcfg_SubparagraphFontSize;
    QCheckBox *kcfg_SubparagraphFontBold;
    QCheckBox *kcfg_SubparagraphFontItalic;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SettingsFormatting)
    {
        if (SettingsFormatting->objectName().isEmpty())
            SettingsFormatting->setObjectName("SettingsFormatting");
        SettingsFormatting->resize(705, 218);
        verticalLayout_2 = new QVBoxLayout(SettingsFormatting);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(SettingsFormatting);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setDocumentMode(true);
        ChapterTab = new QWidget();
        ChapterTab->setObjectName("ChapterTab");
        verticalLayout = new QFormLayout(ChapterTab);
        verticalLayout->setObjectName("verticalLayout");
        lChapterFontFamily = new QLabel(ChapterTab);
        lChapterFontFamily->setObjectName("lChapterFontFamily");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lChapterFontFamily);

        kcfg_ChapterFontFamily = new QFontComboBox(ChapterTab);
        kcfg_ChapterFontFamily->setObjectName("kcfg_ChapterFontFamily");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ChapterFontFamily);

        lChapterFontSize = new QLabel(ChapterTab);
        lChapterFontSize->setObjectName("lChapterFontSize");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lChapterFontSize);

        kcfg_ChapterFontSize = new QSpinBox(ChapterTab);
        kcfg_ChapterFontSize->setObjectName("kcfg_ChapterFontSize");
        kcfg_ChapterFontSize->setMinimum(8);
        kcfg_ChapterFontSize->setMaximum(40);
        kcfg_ChapterFontSize->setValue(14);

        verticalLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ChapterFontSize);

        kcfg_ChapterFontBold = new QCheckBox(ChapterTab);
        kcfg_ChapterFontBold->setObjectName("kcfg_ChapterFontBold");

        verticalLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ChapterFontBold);

        kcfg_ChapterFontItalic = new QCheckBox(ChapterTab);
        kcfg_ChapterFontItalic->setObjectName("kcfg_ChapterFontItalic");

        verticalLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_ChapterFontItalic);

        tabWidget->addTab(ChapterTab, QString());
        SubchapterTab = new QWidget();
        SubchapterTab->setObjectName("SubchapterTab");
        verticalLayout4 = new QFormLayout(SubchapterTab);
        verticalLayout4->setObjectName("verticalLayout4");
        lSubchapterFontFamily = new QLabel(SubchapterTab);
        lSubchapterFontFamily->setObjectName("lSubchapterFontFamily");

        verticalLayout4->setWidget(0, QFormLayout::ItemRole::LabelRole, lSubchapterFontFamily);

        kcfg_SubchapterFontFamily = new QFontComboBox(SubchapterTab);
        kcfg_SubchapterFontFamily->setObjectName("kcfg_SubchapterFontFamily");

        verticalLayout4->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_SubchapterFontFamily);

        lSubchapterFontSize = new QLabel(SubchapterTab);
        lSubchapterFontSize->setObjectName("lSubchapterFontSize");

        verticalLayout4->setWidget(1, QFormLayout::ItemRole::LabelRole, lSubchapterFontSize);

        kcfg_SubchapterFontSize = new QSpinBox(SubchapterTab);
        kcfg_SubchapterFontSize->setObjectName("kcfg_SubchapterFontSize");
        kcfg_SubchapterFontSize->setMinimum(8);
        kcfg_SubchapterFontSize->setMaximum(40);
        kcfg_SubchapterFontSize->setValue(14);

        verticalLayout4->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_SubchapterFontSize);

        kcfg_SubchapterFontBold = new QCheckBox(SubchapterTab);
        kcfg_SubchapterFontBold->setObjectName("kcfg_SubchapterFontBold");

        verticalLayout4->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_SubchapterFontBold);

        kcfg_SubchapterFontItalic = new QCheckBox(SubchapterTab);
        kcfg_SubchapterFontItalic->setObjectName("kcfg_SubchapterFontItalic");

        verticalLayout4->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_SubchapterFontItalic);

        tabWidget->addTab(SubchapterTab, QString());
        SectionTab = new QWidget();
        SectionTab->setObjectName("SectionTab");
        verticalLayout3 = new QFormLayout(SectionTab);
        verticalLayout3->setObjectName("verticalLayout3");
        lSectionFontFamily = new QLabel(SectionTab);
        lSectionFontFamily->setObjectName("lSectionFontFamily");

        verticalLayout3->setWidget(0, QFormLayout::ItemRole::LabelRole, lSectionFontFamily);

        kcfg_SectionFontFamily = new QFontComboBox(SectionTab);
        kcfg_SectionFontFamily->setObjectName("kcfg_SectionFontFamily");

        verticalLayout3->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_SectionFontFamily);

        lSectionFontSize = new QLabel(SectionTab);
        lSectionFontSize->setObjectName("lSectionFontSize");

        verticalLayout3->setWidget(1, QFormLayout::ItemRole::LabelRole, lSectionFontSize);

        kcfg_SectionFontSize = new QSpinBox(SectionTab);
        kcfg_SectionFontSize->setObjectName("kcfg_SectionFontSize");
        kcfg_SectionFontSize->setMinimum(8);
        kcfg_SectionFontSize->setMaximum(40);
        kcfg_SectionFontSize->setValue(14);

        verticalLayout3->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_SectionFontSize);

        kcfg_SectionFontBold = new QCheckBox(SectionTab);
        kcfg_SectionFontBold->setObjectName("kcfg_SectionFontBold");

        verticalLayout3->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_SectionFontBold);

        kcfg_SectionFontItalic = new QCheckBox(SectionTab);
        kcfg_SectionFontItalic->setObjectName("kcfg_SectionFontItalic");

        verticalLayout3->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_SectionFontItalic);

        tabWidget->addTab(SectionTab, QString());
        SubsectionTab = new QWidget();
        SubsectionTab->setObjectName("SubsectionTab");
        verticalLayout6 = new QFormLayout(SubsectionTab);
        verticalLayout6->setObjectName("verticalLayout6");
        lSubsectionFontFamily = new QLabel(SubsectionTab);
        lSubsectionFontFamily->setObjectName("lSubsectionFontFamily");

        verticalLayout6->setWidget(0, QFormLayout::ItemRole::LabelRole, lSubsectionFontFamily);

        kcfg_SubsectionFontFamily = new QFontComboBox(SubsectionTab);
        kcfg_SubsectionFontFamily->setObjectName("kcfg_SubsectionFontFamily");

        verticalLayout6->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_SubsectionFontFamily);

        lSubsetctionFontSize = new QLabel(SubsectionTab);
        lSubsetctionFontSize->setObjectName("lSubsetctionFontSize");

        verticalLayout6->setWidget(1, QFormLayout::ItemRole::LabelRole, lSubsetctionFontSize);

        kcfg_SubsectionFontSize = new QSpinBox(SubsectionTab);
        kcfg_SubsectionFontSize->setObjectName("kcfg_SubsectionFontSize");
        kcfg_SubsectionFontSize->setMinimum(8);
        kcfg_SubsectionFontSize->setMaximum(40);
        kcfg_SubsectionFontSize->setValue(14);

        verticalLayout6->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_SubsectionFontSize);

        kcfg_SubsectionFontBold = new QCheckBox(SubsectionTab);
        kcfg_SubsectionFontBold->setObjectName("kcfg_SubsectionFontBold");

        verticalLayout6->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_SubsectionFontBold);

        kcfg_SubsectionFontItalic = new QCheckBox(SubsectionTab);
        kcfg_SubsectionFontItalic->setObjectName("kcfg_SubsectionFontItalic");

        verticalLayout6->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_SubsectionFontItalic);

        tabWidget->addTab(SubsectionTab, QString());
        ParagraphTab = new QWidget();
        ParagraphTab->setObjectName("ParagraphTab");
        verticalLayout2 = new QFormLayout(ParagraphTab);
        verticalLayout2->setObjectName("verticalLayout2");
        lParagraphFontFamily = new QLabel(ParagraphTab);
        lParagraphFontFamily->setObjectName("lParagraphFontFamily");

        verticalLayout2->setWidget(0, QFormLayout::ItemRole::LabelRole, lParagraphFontFamily);

        kcfg_ParagraphFontFamily = new QFontComboBox(ParagraphTab);
        kcfg_ParagraphFontFamily->setObjectName("kcfg_ParagraphFontFamily");

        verticalLayout2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ParagraphFontFamily);

        lParagrapshFontSize = new QLabel(ParagraphTab);
        lParagrapshFontSize->setObjectName("lParagrapshFontSize");

        verticalLayout2->setWidget(1, QFormLayout::ItemRole::LabelRole, lParagrapshFontSize);

        kcfg_ParagraphFontSize = new QSpinBox(ParagraphTab);
        kcfg_ParagraphFontSize->setObjectName("kcfg_ParagraphFontSize");
        kcfg_ParagraphFontSize->setMinimum(8);
        kcfg_ParagraphFontSize->setMaximum(40);
        kcfg_ParagraphFontSize->setValue(14);

        verticalLayout2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ParagraphFontSize);

        kcfg_ParagraphFontBold = new QCheckBox(ParagraphTab);
        kcfg_ParagraphFontBold->setObjectName("kcfg_ParagraphFontBold");

        verticalLayout2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ParagraphFontBold);

        kcfg_ParagraphFontItalic = new QCheckBox(ParagraphTab);
        kcfg_ParagraphFontItalic->setObjectName("kcfg_ParagraphFontItalic");

        verticalLayout2->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_ParagraphFontItalic);

        tabWidget->addTab(ParagraphTab, QString());
        SubparagraphTab = new QWidget();
        SubparagraphTab->setObjectName("SubparagraphTab");
        verticalLayout5 = new QFormLayout(SubparagraphTab);
        verticalLayout5->setObjectName("verticalLayout5");
        lSubparagraphFontFamily = new QLabel(SubparagraphTab);
        lSubparagraphFontFamily->setObjectName("lSubparagraphFontFamily");

        verticalLayout5->setWidget(0, QFormLayout::ItemRole::LabelRole, lSubparagraphFontFamily);

        kcfg_SubparagraphFontFamily = new QFontComboBox(SubparagraphTab);
        kcfg_SubparagraphFontFamily->setObjectName("kcfg_SubparagraphFontFamily");

        verticalLayout5->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_SubparagraphFontFamily);

        lSubparagraphFontSize = new QLabel(SubparagraphTab);
        lSubparagraphFontSize->setObjectName("lSubparagraphFontSize");

        verticalLayout5->setWidget(1, QFormLayout::ItemRole::LabelRole, lSubparagraphFontSize);

        kcfg_SubparagraphFontSize = new QSpinBox(SubparagraphTab);
        kcfg_SubparagraphFontSize->setObjectName("kcfg_SubparagraphFontSize");
        kcfg_SubparagraphFontSize->setMinimum(8);
        kcfg_SubparagraphFontSize->setMaximum(40);
        kcfg_SubparagraphFontSize->setValue(14);

        verticalLayout5->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_SubparagraphFontSize);

        kcfg_SubparagraphFontBold = new QCheckBox(SubparagraphTab);
        kcfg_SubparagraphFontBold->setObjectName("kcfg_SubparagraphFontBold");

        verticalLayout5->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_SubparagraphFontBold);

        kcfg_SubparagraphFontItalic = new QCheckBox(SubparagraphTab);
        kcfg_SubparagraphFontItalic->setObjectName("kcfg_SubparagraphFontItalic");

        verticalLayout5->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_SubparagraphFontItalic);

        tabWidget->addTab(SubparagraphTab, QString());

        verticalLayout_2->addWidget(tabWidget);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        lChapterFontFamily->setBuddy(kcfg_ChapterFontFamily);
        lChapterFontSize->setBuddy(kcfg_ChapterFontSize);
        lSubchapterFontFamily->setBuddy(kcfg_SubchapterFontFamily);
        lSubchapterFontSize->setBuddy(kcfg_SubchapterFontSize);
        lSectionFontFamily->setBuddy(kcfg_SectionFontFamily);
        lSectionFontSize->setBuddy(kcfg_SectionFontSize);
        lSubsectionFontFamily->setBuddy(kcfg_SubsectionFontFamily);
        lSubsetctionFontSize->setBuddy(kcfg_SubsectionFontSize);
        lParagraphFontFamily->setBuddy(kcfg_ParagraphFontFamily);
        lParagrapshFontSize->setBuddy(kcfg_ParagraphFontSize);
        lSubparagraphFontFamily->setBuddy(kcfg_SubparagraphFontFamily);
        lSubparagraphFontSize->setBuddy(kcfg_SubparagraphFontSize);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SettingsFormatting);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SettingsFormatting);
    } // setupUi

    void retranslateUi(QWidget *SettingsFormatting)
    {
        lChapterFontFamily->setText(tr2i18n("Fon&t Family:", nullptr));
        lChapterFontSize->setText(tr2i18n("Font Si&ze:", nullptr));
        kcfg_ChapterFontBold->setText(tr2i18n("Bold", nullptr));
        kcfg_ChapterFontItalic->setText(tr2i18n("Italic", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(ChapterTab), tr2i18n("Chapter Font", nullptr));
        lSubchapterFontFamily->setText(tr2i18n("Fon&t Family:", nullptr));
        lSubchapterFontSize->setText(tr2i18n("Font Si&ze:", nullptr));
        kcfg_SubchapterFontBold->setText(tr2i18n("Bold", nullptr));
        kcfg_SubchapterFontItalic->setText(tr2i18n("Italic", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(SubchapterTab), tr2i18n("Subchapter Font", nullptr));
        lSectionFontFamily->setText(tr2i18n("Fon&t Family:", nullptr));
        lSectionFontSize->setText(tr2i18n("Font Si&ze:", nullptr));
        kcfg_SectionFontBold->setText(tr2i18n("Bold", nullptr));
        kcfg_SectionFontItalic->setText(tr2i18n("Italic", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(SectionTab), tr2i18n("Section Font", nullptr));
        lSubsectionFontFamily->setText(tr2i18n("Fon&t Family:", nullptr));
        lSubsetctionFontSize->setText(tr2i18n("Font Si&ze:", nullptr));
        kcfg_SubsectionFontBold->setText(tr2i18n("Bold", nullptr));
        kcfg_SubsectionFontItalic->setText(tr2i18n("Italic", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(SubsectionTab), tr2i18n("Subsection Font", nullptr));
        lParagraphFontFamily->setText(tr2i18n("Fon&t Family:", nullptr));
        lParagrapshFontSize->setText(tr2i18n("Font Si&ze:", nullptr));
        kcfg_ParagraphFontBold->setText(tr2i18n("Bold", nullptr));
        kcfg_ParagraphFontItalic->setText(tr2i18n("Italic", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(ParagraphTab), tr2i18n("Paragraph Font", nullptr));
        lSubparagraphFontFamily->setText(tr2i18n("Fon&t Family:", nullptr));
        lSubparagraphFontSize->setText(tr2i18n("Font Si&ze:", nullptr));
        kcfg_SubparagraphFontBold->setText(tr2i18n("Bold", nullptr));
        kcfg_SubparagraphFontItalic->setText(tr2i18n("Italic", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(SubparagraphTab), tr2i18n("Subparagraph Font", nullptr));
        (void)SettingsFormatting;
    } // retranslateUi

};

namespace Ui {
    class SettingsFormatting: public Ui_SettingsFormatting {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FORMATING_H

