/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Cantor.R.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef RSERVER_INTERFACE_H
#define RSERVER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Cantor.R
 */
class OrgKdeCantorRInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Cantor.R"; }

public:
    OrgKdeCantorRInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeCantorRInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> answerRequest(const QString &answer)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(answer);
        return asyncCallWithArgumentList(QStringLiteral("answerRequest"), argumentList);
    }

    inline QDBusPendingReply<> runCommand(const QString &cmd, bool internal)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(cmd) << QVariant::fromValue(internal);
        return asyncCallWithArgumentList(QStringLiteral("runCommand"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void expressionFinished(int returnCode, const QString &text, const QStringList &files);
    void inputRequested(const QString &prompt);
    void ready();
    void requestAnswered();
    void statusChanged(int status);
};

namespace org {
  namespace kde {
    namespace Cantor {
      using R = ::OrgKdeCantorRInterface;
    }
  }
}

#endif
