/********************************************************************************
** Form generated from reading UI file 'plot3ddlg.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLOT3DDLG_H
#define UI_PLOT3DDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_Plot3dAssistantBase
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KLineEdit *expression;
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_2;
    KLineEdit *variable1;
    QLabel *label_3;
    KLineEdit *min1;
    QLabel *label_4;
    KLineEdit *max1;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QLabel *label_5;
    KLineEdit *variable2;
    QLabel *label_6;
    KLineEdit *min2;
    QLabel *label_7;
    KLineEdit *max2;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *Plot3dAssistantBase)
    {
        if (Plot3dAssistantBase->objectName().isEmpty())
            Plot3dAssistantBase->setObjectName("Plot3dAssistantBase");
        Plot3dAssistantBase->resize(459, 263);
        formLayout = new QFormLayout(Plot3dAssistantBase);
        formLayout->setObjectName("formLayout");
        label = new QLabel(Plot3dAssistantBase);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        expression = new KLineEdit(Plot3dAssistantBase);
        expression->setObjectName("expression");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, expression);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        groupBox = new QGroupBox(Plot3dAssistantBase);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        groupBox->setCheckable(false);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        variable1 = new KLineEdit(groupBox);
        variable1->setObjectName("variable1");

        gridLayout->addWidget(variable1, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        min1 = new KLineEdit(groupBox);
        min1->setObjectName("min1");

        gridLayout->addWidget(min1, 1, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        max1 = new KLineEdit(groupBox);
        max1->setObjectName("max1");

        gridLayout->addWidget(max1, 2, 1, 1, 1);


        horizontalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(Plot3dAssistantBase);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setFlat(true);
        groupBox_2->setCheckable(false);
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        gridLayout_2->addWidget(label_5, 0, 0, 1, 1);

        variable2 = new KLineEdit(groupBox_2);
        variable2->setObjectName("variable2");

        gridLayout_2->addWidget(variable2, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 1, 0, 1, 1);

        min2 = new KLineEdit(groupBox_2);
        min2->setObjectName("min2");

        gridLayout_2->addWidget(min2, 1, 1, 1, 1);

        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 2, 0, 1, 1);

        max2 = new KLineEdit(groupBox_2);
        max2->setObjectName("max2");

        gridLayout_2->addWidget(max2, 2, 1, 1, 1);


        horizontalLayout->addWidget(groupBox_2);


        formLayout->setLayout(1, QFormLayout::ItemRole::SpanningRole, horizontalLayout);

        buttonBox = new QDialogButtonBox(Plot3dAssistantBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, buttonBox);

        QWidget::setTabOrder(expression, variable1);
        QWidget::setTabOrder(variable1, min1);
        QWidget::setTabOrder(min1, max1);

        retranslateUi(Plot3dAssistantBase);

        QMetaObject::connectSlotsByName(Plot3dAssistantBase);
    } // setupUi

    void retranslateUi(QWidget *Plot3dAssistantBase)
    {
        label->setText(tr2i18n("Expression:", nullptr));
        groupBox->setTitle(tr2i18n("1st Variable", nullptr));
        label_2->setText(tr2i18n("Name", nullptr));
        label_3->setText(tr2i18n("Minimum:", nullptr));
        label_4->setText(tr2i18n("Maximum:", nullptr));
        groupBox_2->setTitle(tr2i18n("2nd Variable", nullptr));
        label_5->setText(tr2i18n("Name", nullptr));
        label_6->setText(tr2i18n("Minimum:", nullptr));
        label_7->setText(tr2i18n("Maximum:", nullptr));
        (void)Plot3dAssistantBase;
    } // retranslateUi

};

namespace Ui {
    class Plot3dAssistantBase: public Ui_Plot3dAssistantBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLOT3DDLG_H

