/********************************************************************************
** Form generated from reading UI file 'newvardlg.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWVARDLG_H
#define UI_NEWVARDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_NewVariableDialogBase
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KLineEdit *name;
    QLabel *label_2;
    KLineEdit *value;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *NewVariableDialogBase)
    {
        if (NewVariableDialogBase->objectName().isEmpty())
            NewVariableDialogBase->setObjectName("NewVariableDialogBase");
        NewVariableDialogBase->resize(428, 96);
        formLayout = new QFormLayout(NewVariableDialogBase);
        formLayout->setObjectName("formLayout");
        label = new QLabel(NewVariableDialogBase);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        name = new KLineEdit(NewVariableDialogBase);
        name->setObjectName("name");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, name);

        label_2 = new QLabel(NewVariableDialogBase);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        value = new KLineEdit(NewVariableDialogBase);
        value->setObjectName("value");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, value);

        buttonBox = new QDialogButtonBox(NewVariableDialogBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, buttonBox);


        retranslateUi(NewVariableDialogBase);

        QMetaObject::connectSlotsByName(NewVariableDialogBase);
    } // setupUi

    void retranslateUi(QWidget *NewVariableDialogBase)
    {
        label->setText(tr2i18n("Name:", nullptr));
        label_2->setText(tr2i18n("Value:", nullptr));
        (void)NewVariableDialogBase;
    } // retranslateUi

};

namespace Ui {
    class NewVariableDialogBase: public Ui_NewVariableDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWVARDLG_H

