// This file is generated by kconfig_compiler_kf6 from cantor_libs.kcfg.
// All changes you do to this file will be lost.
#ifndef CANTORLIBSSETTINGS_H
#define CANTORLIBSSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <QStandardPaths>

class CantorLibsSettings : public KConfigSkeleton
{
  public:

    static CantorLibsSettings *self();
    ~CantorLibsSettings() override;

    /**
      Get Path to the latex executable
    */
    static
    QString latexCommand()
    {
      return self()->mLatexCommand;
    }

    /**
      Is Path to the latex executable Immutable
    */
    static
    bool isLatexCommandImmutable()
    {
      return self()->isImmutable( QStringLiteral( "latexCommand" ) );
    }

    /**
      Get Path to the dvips executable
    */
    static
    QString dvipsCommand()
    {
      return self()->mDvipsCommand;
    }

    /**
      Is Path to the dvips executable Immutable
    */
    static
    bool isDvipsCommandImmutable()
    {
      return self()->isImmutable( QStringLiteral( "dvipsCommand" ) );
    }

  protected:
    CantorLibsSettings();
    friend class CantorLibsSettingsHelper;


    // Cantor
    QString mLatexCommand;
    QString mDvipsCommand;
};

#endif

