/****************************************************************************
** Meta object code from reading C++ file 'defaultvariablemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../cantor-26.07.80/src/lib/defaultvariablemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'defaultvariablemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::DefaultVariableModel::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::DefaultVariableModel",
        "variablesAdded",
        "",
        "variables",
        "variablesRemoved",
        "functionsAdded",
        "names",
        "functionsRemoved",
        "funcs",
        "initialModelPopulated",
        "addVariable",
        "name",
        "value",
        "Cantor::DefaultVariableModel::Variable",
        "variable",
        "removeVariable",
        "clearVariables",
        "clearFunctions",
        "session",
        "Session*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'variablesAdded'
        QtMocHelpers::SignalData<void(const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'variablesRemoved'
        QtMocHelpers::SignalData<void(const QStringList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'functionsAdded'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'functionsRemoved'
        QtMocHelpers::SignalData<void(const QStringList)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 8 },
        }}),
        // Signal 'initialModelPopulated'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addVariable'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'addVariable'
        QtMocHelpers::SlotData<void(const Cantor::DefaultVariableModel::Variable &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'removeVariable'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'removeVariable'
        QtMocHelpers::SlotData<void(const Cantor::DefaultVariableModel::Variable &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'clearVariables'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearFunctions'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'session'
        QtMocHelpers::PropertyData<Session*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DefaultVariableModel, qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::DefaultVariableModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTableModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t>.metaTypes,
    nullptr
} };

void Cantor::DefaultVariableModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DefaultVariableModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->variablesAdded((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->variablesRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->functionsAdded((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->functionsRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->initialModelPopulated(); break;
        case 5: _t->addVariable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->addVariable((*reinterpret_cast<std::add_pointer_t<Cantor::DefaultVariableModel::Variable>>(_a[1]))); break;
        case 7: _t->removeVariable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->removeVariable((*reinterpret_cast<std::add_pointer_t<Cantor::DefaultVariableModel::Variable>>(_a[1]))); break;
        case 9: _t->clearVariables(); break;
        case 10: _t->clearFunctions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DefaultVariableModel::*)(const QStringList & )>(_a, &DefaultVariableModel::variablesAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DefaultVariableModel::*)(const QStringList & )>(_a, &DefaultVariableModel::variablesRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DefaultVariableModel::*)(const QStringList & )>(_a, &DefaultVariableModel::functionsAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DefaultVariableModel::*)(const QStringList )>(_a, &DefaultVariableModel::functionsRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DefaultVariableModel::*)()>(_a, &DefaultVariableModel::initialModelPopulated, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Session* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Session**>(_v) = _t->session(); break;
        default: break;
        }
    }
}

const QMetaObject *Cantor::DefaultVariableModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::DefaultVariableModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor20DefaultVariableModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int Cantor::DefaultVariableModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Cantor::DefaultVariableModel::variablesAdded(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Cantor::DefaultVariableModel::variablesRemoved(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Cantor::DefaultVariableModel::functionsAdded(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Cantor::DefaultVariableModel::functionsRemoved(const QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Cantor::DefaultVariableModel::initialModelPopulated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
