/****************************************************************************
** Meta object code from reading C++ file 'commandentry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../cantor-26.07.80/src/commandentry.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'commandentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12CommandEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto CommandEntry::qt_create_metaobjectdata<qt_meta_tag_ZN12CommandEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CommandEntry",
        "evaluateCurrentItem",
        "",
        "evaluate",
        "WorksheetEntry::EvaluationOption",
        "evalOp",
        "addInformation",
        "removeResults",
        "removeResult",
        "Cantor::Result*",
        "result",
        "collapseResults",
        "expandResults",
        "excludeFromExecution",
        "addToExecution",
        "updateEntry",
        "updatePrompt",
        "postfix",
        "expressionChangedStatus",
        "Cantor::Expression::Status",
        "showAdditionalInformationPrompt",
        "startRemoving",
        "warn",
        "moveToNextItem",
        "pos",
        "x",
        "moveToPreviousItem",
        "populateMenu",
        "QMenu*",
        "QPointF",
        "updateAfterSettingsChanges",
        "invalidate",
        "resultDeleted",
        "clearResultItems",
        "removeResultItem",
        "index",
        "replaceResultItem",
        "changeResultCollapsingAction",
        "showHelp",
        "toggleEnabled",
        "backgroundColorChanged",
        "QAction*",
        "textColorChanged",
        "fontBoldTriggered",
        "fontItalicTriggered",
        "fontIncreaseTriggered",
        "fontDecreaseTriggered",
        "fontSelectTriggered",
        "resetFontTriggered",
        "animatePromptItem",
        "setMidPrompt",
        "setHidePrompt"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'evaluateCurrentItem'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool(WorksheetEntry::EvaluationOption)>(3, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'evaluate'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'addInformation'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeResults'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeResult'
        QtMocHelpers::SlotData<void(Cantor::Result *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'collapseResults'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'expandResults'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'excludeFromExecution'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addToExecution'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateEntry'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePrompt'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'updatePrompt'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'expressionChangedStatus'
        QtMocHelpers::SlotData<void(Cantor::Expression::Status)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'showAdditionalInformationPrompt'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'startRemoving'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'startRemoving'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveToNextItem'
        QtMocHelpers::SlotData<void(int, qreal)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::QReal, 25 },
        }}),
        // Slot 'moveToPreviousItem'
        QtMocHelpers::SlotData<void(int, qreal)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::QReal, 25 },
        }}),
        // Slot 'populateMenu'
        QtMocHelpers::SlotData<void(QMenu *, QPointF)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 }, { 0x80000000 | 29, 2 },
        }}),
        // Slot 'updateAfterSettingsChanges'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invalidate'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resultDeleted'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearResultItems'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeResultItem'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'replaceResultItem'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'changeResultCollapsingAction'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showHelp'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleEnabled'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'backgroundColorChanged'
        QtMocHelpers::SlotData<void(QAction *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 2 },
        }}),
        // Slot 'textColorChanged'
        QtMocHelpers::SlotData<void(QAction *)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 2 },
        }}),
        // Slot 'fontBoldTriggered'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fontItalicTriggered'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fontIncreaseTriggered'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fontDecreaseTriggered'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fontSelectTriggered'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetFontTriggered'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'animatePromptItem'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setMidPrompt'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setHidePrompt'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CommandEntry, qt_meta_tag_ZN12CommandEntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CommandEntry::staticMetaObject = { {
    QMetaObject::SuperData::link<WorksheetEntry::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CommandEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CommandEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12CommandEntryE_t>.metaTypes,
    nullptr
} };

void CommandEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommandEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->evaluateCurrentItem();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->evaluate((*reinterpret_cast<std::add_pointer_t<WorksheetEntry::EvaluationOption>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->evaluate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->addInformation(); break;
        case 4: _t->removeResults(); break;
        case 5: _t->removeResult((*reinterpret_cast<std::add_pointer_t<Cantor::Result*>>(_a[1]))); break;
        case 6: _t->collapseResults(); break;
        case 7: _t->expandResults(); break;
        case 8: _t->excludeFromExecution(); break;
        case 9: _t->addToExecution(); break;
        case 10: _t->updateEntry(); break;
        case 11: _t->updatePrompt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->updatePrompt(); break;
        case 13: _t->expressionChangedStatus((*reinterpret_cast<std::add_pointer_t<Cantor::Expression::Status>>(_a[1]))); break;
        case 14: _t->showAdditionalInformationPrompt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->startRemoving((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->startRemoving(); break;
        case 17: _t->moveToNextItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 18: _t->moveToPreviousItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 19: _t->populateMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 20: _t->updateAfterSettingsChanges(); break;
        case 21: _t->invalidate(); break;
        case 22: _t->resultDeleted(); break;
        case 23: _t->clearResultItems(); break;
        case 24: _t->removeResultItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->replaceResultItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->changeResultCollapsingAction(); break;
        case 27: _t->showHelp(); break;
        case 28: _t->toggleEnabled(); break;
        case 29: _t->backgroundColorChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 30: _t->textColorChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 31: _t->fontBoldTriggered(); break;
        case 32: _t->fontItalicTriggered(); break;
        case 33: _t->fontIncreaseTriggered(); break;
        case 34: _t->fontDecreaseTriggered(); break;
        case 35: _t->fontSelectTriggered(); break;
        case 36: _t->resetFontTriggered(); break;
        case 37: _t->animatePromptItem(); break;
        case 38: _t->setMidPrompt(); break;
        case 39: _t->setHidePrompt(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *CommandEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommandEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CommandEntryE_t>.strings))
        return static_cast<void*>(this);
    return WorksheetEntry::qt_metacast(_clname);
}

int CommandEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorksheetEntry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    return _id;
}
QT_WARNING_POP
