/********************************************************************************
** Form generated from reading UI file 'extendedsearchbar.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTENDEDSEARCHBAR_H
#define UI_EXTENDEDSEARCHBAR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klineedit.h>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_ExtendedSearchBar
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QToolButton *close;
    QSpacerItem *verticalSpacer_2;
    QLabel *label;
    KLineEdit *pattern;
    QPushButton *next;
    QPushButton *previous;
    QVBoxLayout *verticalLayout;
    QToolButton *openStandard;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    KLineEdit *replacement;
    QPushButton *replace;
    QPushButton *replaceAll;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    KLineEdit *searchFlagsList;
    QToolButton *addFlag;
    QToolButton *removeFlag;
    QCheckBox *matchCase;
    KSqueezedTextLabel *status;

    void setupUi(QWidget *ExtendedSearchBar)
    {
        if (ExtendedSearchBar->objectName().isEmpty())
            ExtendedSearchBar->setObjectName("ExtendedSearchBar");
        ExtendedSearchBar->resize(995, 97);
        gridLayout = new QGridLayout(ExtendedSearchBar);
        gridLayout->setObjectName("gridLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        close = new QToolButton(ExtendedSearchBar);
        close->setObjectName("close");
        close->setAutoRaise(true);

        verticalLayout_2->addWidget(close);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        gridLayout->addLayout(verticalLayout_2, 0, 0, 4, 1);

        label = new QLabel(ExtendedSearchBar);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 1, 1, 1);

        pattern = new KLineEdit(ExtendedSearchBar);
        pattern->setObjectName("pattern");
        pattern->setProperty("showClearButton", QVariant(true));

        gridLayout->addWidget(pattern, 0, 2, 1, 1);

        next = new QPushButton(ExtendedSearchBar);
        next->setObjectName("next");

        gridLayout->addWidget(next, 0, 3, 1, 1);

        previous = new QPushButton(ExtendedSearchBar);
        previous->setObjectName("previous");

        gridLayout->addWidget(previous, 0, 4, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        openStandard = new QToolButton(ExtendedSearchBar);
        openStandard->setObjectName("openStandard");
        openStandard->setAutoRaise(true);

        verticalLayout->addWidget(openStandard);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 5, 3, 1);

        label_2 = new QLabel(ExtendedSearchBar);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 1, 1, 1);

        replacement = new KLineEdit(ExtendedSearchBar);
        replacement->setObjectName("replacement");
        replacement->setProperty("showClearButton", QVariant(true));

        gridLayout->addWidget(replacement, 1, 2, 1, 1);

        replace = new QPushButton(ExtendedSearchBar);
        replace->setObjectName("replace");

        gridLayout->addWidget(replace, 1, 3, 1, 1);

        replaceAll = new QPushButton(ExtendedSearchBar);
        replaceAll->setObjectName("replaceAll");

        gridLayout->addWidget(replaceAll, 1, 4, 1, 1);

        line = new QFrame(ExtendedSearchBar);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 2, 1, 1, 4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(ExtendedSearchBar);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        searchFlagsList = new KLineEdit(ExtendedSearchBar);
        searchFlagsList->setObjectName("searchFlagsList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(4);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(searchFlagsList->sizePolicy().hasHeightForWidth());
        searchFlagsList->setSizePolicy(sizePolicy);
        searchFlagsList->setReadOnly(true);

        horizontalLayout->addWidget(searchFlagsList);

        addFlag = new QToolButton(ExtendedSearchBar);
        addFlag->setObjectName("addFlag");

        horizontalLayout->addWidget(addFlag);

        removeFlag = new QToolButton(ExtendedSearchBar);
        removeFlag->setObjectName("removeFlag");

        horizontalLayout->addWidget(removeFlag);

        matchCase = new QCheckBox(ExtendedSearchBar);
        matchCase->setObjectName("matchCase");

        horizontalLayout->addWidget(matchCase);

        status = new KSqueezedTextLabel(ExtendedSearchBar);
        status->setObjectName("status");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(status->sizePolicy().hasHeightForWidth());
        status->setSizePolicy(sizePolicy1);
        status->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(status);


        gridLayout->addLayout(horizontalLayout, 3, 1, 1, 5);


        retranslateUi(ExtendedSearchBar);

        QMetaObject::connectSlotsByName(ExtendedSearchBar);
    } // setupUi

    void retranslateUi(QWidget *ExtendedSearchBar)
    {
        ExtendedSearchBar->setWindowTitle(tr2i18n("SearchBar", nullptr));
        close->setText(tr2i18n("...", nullptr));
        label->setText(tr2i18n("Find:", nullptr));
        next->setText(tr2i18n("&Next", nullptr));
        previous->setText(tr2i18n("&Previous", nullptr));
        openStandard->setText(tr2i18n("...", nullptr));
        label_2->setText(tr2i18n("Replace:", nullptr));
        replace->setText(tr2i18n("&Replace", nullptr));
        replaceAll->setText(tr2i18n("Replace &All", nullptr));
        label_3->setText(tr2i18n("Search in:", nullptr));
        addFlag->setText(tr2i18n("...", nullptr));
        removeFlag->setText(tr2i18n("...", nullptr));
        matchCase->setText(tr2i18n("&Match case", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ExtendedSearchBar: public Ui_ExtendedSearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTENDEDSEARCHBAR_H

