/********************************************************************************
** Form generated from reading UI file 'qthelpconfigeditdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QTHELPCONFIGEDITDIALOG_H
#define UI_QTHELPCONFIGEDITDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <klocalizedstring.h>
#include "kiconbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_QtHelpConfigEditDialog
{
public:
    QFormLayout *formLayout;
    QLabel *lIcon;
    KIconButton *qchIcon;
    QLabel *lName;
    QLineEdit *qchName;
    QLabel *lPath;
    KUrlRequester *qchRequester;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QtHelpConfigEditDialog)
    {
        if (QtHelpConfigEditDialog->objectName().isEmpty())
            QtHelpConfigEditDialog->setObjectName("QtHelpConfigEditDialog");
        QtHelpConfigEditDialog->resize(400, 174);
        formLayout = new QFormLayout(QtHelpConfigEditDialog);
        formLayout->setObjectName("formLayout");
        lIcon = new QLabel(QtHelpConfigEditDialog);
        lIcon->setObjectName("lIcon");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, lIcon);

        qchIcon = new KIconButton(QtHelpConfigEditDialog);
        qchIcon->setObjectName("qchIcon");
        qchIcon->setIconSize(16);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, qchIcon);

        lName = new QLabel(QtHelpConfigEditDialog);
        lName->setObjectName("lName");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lName);

        qchName = new QLineEdit(QtHelpConfigEditDialog);
        qchName->setObjectName("qchName");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, qchName);

        lPath = new QLabel(QtHelpConfigEditDialog);
        lPath->setObjectName("lPath");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, lPath);

        qchRequester = new KUrlRequester(QtHelpConfigEditDialog);
        qchRequester->setObjectName("qchRequester");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(qchRequester->sizePolicy().hasHeightForWidth());
        qchRequester->setSizePolicy(sizePolicy);
        qchRequester->setNameFilter(QString::fromUtf8("*.qch|Qt Compressed Help (.qch)"));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, qchRequester);

        buttonBox = new QDialogButtonBox(QtHelpConfigEditDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, buttonBox);


        retranslateUi(QtHelpConfigEditDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, QtHelpConfigEditDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, QtHelpConfigEditDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(QtHelpConfigEditDialog);
    } // setupUi

    void retranslateUi(QDialog *QtHelpConfigEditDialog)
    {
        lIcon->setText(tr2i18n("Icon:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        qchIcon->setToolTip(tr2i18n("Select an icon", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        lName->setText(tr2i18n("Name:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        qchName->setToolTip(tr2i18n("Enter a name", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        qchName->setPlaceholderText(tr2i18n("Select a name...", "@info:placeholder"));
        lPath->setText(tr2i18n("Path:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        qchRequester->setToolTip(tr2i18n("Select a Qt Help file...", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        qchRequester->setPlaceholderText(tr2i18n("Select a Qt Help file...", "@info:placeholder"));
        (void)QtHelpConfigEditDialog;
    } // retranslateUi

};

namespace Ui {
    class QtHelpConfigEditDialog: public Ui_QtHelpConfigEditDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QTHELPCONFIGEDITDIALOG_H

