    int packc = 6;
    const char *pack[] = {
        "datasets",
        "utils",
        "grDevices",
        "graphics",
        "stats",
        "methods"
    };
    int packobjc[] = {
        108,
        231,
        123,
        87,
        458,
        201
    };
    const char *packobj[] = {
        "ability.cov",
        "airmiles",
        "AirPassengers",
        "airquality",
        "anscombe",
        "attenu",
        "attitude",
        "austres",
        "beaver1",
        "beaver2",
        "BJsales",
        "BJsales.lead",
        "BOD",
        "cars",
        "ChickWeight",
        "chickwts",
        "co2",
        "CO2",
        "crimtab",
        "discoveries",
        "DNase",
        "esoph",
        "euro",
        "euro.cross",
        "eurodist",
        "EuStockMarkets",
        "faithful",
        "fdeaths",
        "Formaldehyde",
        "freeny",
        "freeny.x",
        "freeny.y",
        "gait",
        "HairEyeColor",
        "Harman23.cor",
        "Harman74.cor",
        "Indometh",
        "infert",
        "InsectSprays",
        "iris",
        "iris3",
        "islands",
        "JohnsonJohnson",
        "LakeHuron",
        "ldeaths",
        "lh",
        "LifeCycleSavings",
        "Loblolly",
        "longley",
        "lynx",
        "mdeaths",
        "morley",
        "mtcars",
        "nhtemp",
        "Nile",
        "nottem",
        "npk",
        "occupationalStatus",
        "Orange",
        "OrchardSprays",
        "penguins",
        "penguins_raw",
        "PlantGrowth",
        "precip",
        "presidents",
        "pressure",
        "Puromycin",
        "quakes",
        "randu",
        "rivers",
        "rock",
        "Seatbelts",
        "sleep",
        "stack.loss",
        "stack.x",
        "stackloss",
        "state.abb",
        "state.area",
        "state.center",
        "state.division",
        "state.name",
        "state.region",
        "state.x77",
        "sunspot.m2014",
        "sunspot.month",
        "sunspot.year",
        "sunspots",
        "swiss",
        "Theoph",
        "Titanic",
        "ToothGrowth",
        "treering",
        "trees",
        "UCBAdmissions",
        "UKDriverDeaths",
        "UKgas",
        "USAccDeaths",
        "USArrests",
        "UScitiesD",
        "USJudgeRatings",
        "USPersonalExpenditure",
        "uspop",
        "VADeaths",
        "volcano",
        "warpbreaks",
        "women",
        "WorldPhones",
        "WWWusage",
        "?",
        "adist",
        "alarm",
        "apropos",
        "aregexec",
        "argsAnywhere",
        "as.person",
        "as.personList",
        "as.relistable",
        "as.roman",
        "asDateBuilt",
        "askYesNo",
        "aspell",
        "aspell_package_C_files",
        "aspell_package_R_files",
        "aspell_package_Rd_files",
        "aspell_package_vignettes",
        "aspell_write_personal_dictionary_file",
        "assignInMyNamespace",
        "assignInNamespace",
        "available.packages",
        "bibentry",
        "bitstring",
        "browseEnv",
        "browseURL",
        "browseVignettes",
        "bug.report",
        "capture.output",
        "changedFiles",
        "charClass",
        "checkCRAN",
        "chooseBioCmirror",
        "chooseCRANmirror",
        "citation",
        "cite",
        "citeNatbib",
        "citEntry",
        "citFooter",
        "citHeader",
        "close.socket",
        "clrhash",
        "combn",
        "compareVersion",
        "contrib.url",
        "count.fields",
        "create.post",
        "data",
        "data.entry",
        "dataentry",
        "de",
        "de.ncols",
        "de.restore",
        "de.setup",
        "debugcall",
        "debugger",
        "demo",
        "download.file",
        "download.packages",
        "dump.frames",
        "edit",
        "emacs",
        "example",
        "file_test",
        "file.edit",
        "fileSnapshot",
        "find",
        "findCRANmirror",
        "findLineNum",
        "findMatches",
        "fix",
        "fixInNamespace",
        "flush.console",
        "formatOL",
        "formatUL",
        "getAnywhere",
        "getCRANmirrors",
        "getFromNamespace",
        "gethash",
        "getParseData",
        "getParseText",
        "getS3method",
        "getSrcDirectory",
        "getSrcFilename",
        "getSrcLocation",
        "getSrcref",
        "getTxtProgressBar",
        "glob2rx",
        "globalVariables",
        "hashtab",
        "hasName",
        "head",
        "head.matrix",
        "help",
        "help.request",
        "help.search",
        "help.start",
        "history",
        "hsearch_db",
        "hsearch_db_concepts",
        "hsearch_db_keywords",
        "install.packages",
        "installed.packages",
        "is.hashtab",
        "is.relistable",
        "isS3method",
        "isS3stdGeneric",
        "limitedLabels",
        "loadhistory",
        "localeToCharset",
        "ls.str",
        "lsf.str",
        "maintainer",
        "make.packages.html",
        "make.socket",
        "makeRweaveLatexCodeRunner",
        "maphash",
        "memory.limit",
        "memory.size",
        "menu",
        "methods",
        "mirror2html",
        "modifyList",
        "new.packages",
        "news",
        "nsl",
        "numhash",
        "object.size",
        "old.packages",
        "osVersion",
        "package.skeleton",
        "packageDate",
        "packageDescription",
        "packageName",
        "packageStatus",
        "packageVersion",
        "page",
        "person",
        "personList",
        "pico",
        "process.events",
        "prompt",
        "promptData",
        "promptImport",
        "promptPackage",
        "rc.getOption",
        "rc.options",
        "rc.settings",
        "rc.status",
        "read.csv",
        "read.csv2",
        "read.delim",
        "read.delim2",
        "read.DIF",
        "read.fortran",
        "read.fwf",
        "read.socket",
        "read.table",
        "readCitationFile",
        "recover",
        "relist",
        "remhash",
        "remove.packages",
        "removeSource",
        "Rprof",
        "Rprofmem",
        "RShowDoc",
        "RSiteSearch",
        "rtags",
        "Rtangle",
        "RtangleFinish",
        "RtangleOptions",
        "RtangleRuncode",
        "RtangleSetup",
        "RtangleWritedoc",
        "RweaveChunkPrefix",
        "RweaveEvalWithOpt",
        "RweaveLatex",
        "RweaveLatexFinish",
        "RweaveLatexOptions",
        "RweaveLatexSetup",
        "RweaveLatexWritedoc",
        "RweaveTryStop",
        "savehistory",
        "select.list",
        "sessionInfo",
        "setBreakpoint",
        "sethash",
        "setRepositories",
        "setTxtProgressBar",
        "stack",
        "Stangle",
        "str",
        "strcapture",
        "strOptions",
        "summaryRprof",
        "suppressForeignCheck",
        "Sweave",
        "SweaveGetSourceName",
        "SweaveHooks",
        "SweaveSyntaxLatex",
        "SweaveSyntaxNoweb",
        "SweaveSyntConv",
        "tail",
        "tail.matrix",
        "tar",
        "timestamp",
        "toBibtex",
        "toLatex",
        "txtProgressBar",
        "type.convert",
        "typhash",
        "undebugcall",
        "unstack",
        "untar",
        "unzip",
        "update.packages",
        "upgrade",
        "url.show",
        "URLdecode",
        "URLencode",
        "vi",
        "View",
        "vignette",
        "warnErrList",
        "write.csv",
        "write.csv2",
        "write.socket",
        "write.table",
        "xedit",
        "xemacs",
        "zip",
        "adjustcolor",
        "as.graphicsAnnot",
        "as.raster",
        "axisTicks",
        "bitmap",
        "blues9",
        "bmp",
        "boxplot.stats",
        "cairo_pdf",
        "cairo_ps",
        "cairoSymbolFont",
        "check.options",
        "chull",
        "CIDFont",
        "cm",
        "cm.colors",
        "col2rgb",
        "colorConverter",
        "colorRamp",
        "colorRampPalette",
        "colors",
        "colorspaces",
        "colours",
        "contourLines",
        "convertColor",
        "densCols",
        "dev.capabilities",
        "dev.capture",
        "dev.control",
        "dev.copy",
        "dev.copy2eps",
        "dev.copy2pdf",
        "dev.cur",
        "dev.flush",
        "dev.hold",
        "dev.interactive",
        "dev.list",
        "dev.new",
        "dev.next",
        "dev.off",
        "dev.prev",
        "dev.print",
        "dev.set",
        "dev.size",
        "dev2bitmap",
        "devAskNewPage",
        "deviceIsInteractive",
        "embedFonts",
        "embedGlyphs",
        "extendrange",
        "getGraphicsEvent",
        "getGraphicsEventEnv",
        "glyphAnchor",
        "glyphFont",
        "glyphFontList",
        "glyphFontVariation",
        "glyphHeight",
        "glyphHeightBottom",
        "glyphInfo",
        "glyphJust",
        "glyphWidth",
        "glyphWidthLeft",
        "graphics.off",
        "gray",
        "gray.colors",
        "grey",
        "grey.colors",
        "grSoftVersion",
        "hcl",
        "hcl.colors",
        "hcl.pals",
        "heat.colors",
        "Hershey",
        "hsv",
        "is.raster",
        "jpeg",
        "make.rgb",
        "n2mfrow",
        "nclass.FD",
        "nclass.scott",
        "nclass.Sturges",
        "palette",
        "palette.colors",
        "palette.pals",
        "pdf",
        "pdf.options",
        "pdfFonts",
        "pictex",
        "png",
        "postscript",
        "postscriptFonts",
        "ps.options",
        "quartz",
        "quartz.options",
        "quartz.save",
        "quartzFont",
        "quartzFonts",
        "rainbow",
        "recordGraphics",
        "recordPlot",
        "replayPlot",
        "rgb",
        "rgb2hsv",
        "savePlot",
        "setEPS",
        "setGraphicsEventEnv",
        "setGraphicsEventHandlers",
        "setPS",
        "svg",
        "terrain.colors",
        "tiff",
        "topo.colors",
        "trans3d",
        "Type1Font",
        "x11",
        "X11",
        "X11.options",
        "X11Font",
        "X11Fonts",
        "xfig",
        "xy.coords",
        "xyTable",
        "xyz.coords",
        "abline",
        "arrows",
        "assocplot",
        "axis",
        "Axis",
        "axis.Date",
        "axis.POSIXct",
        "axTicks",
        "barplot",
        "barplot.default",
        "box",
        "boxplot",
        "boxplot.default",
        "boxplot.matrix",
        "bxp",
        "cdplot",
        "clip",
        "close.screen",
        "co.intervals",
        "contour",
        "contour.default",
        "coplot",
        "curve",
        "dotchart",
        "erase.screen",
        "filled.contour",
        "fourfoldplot",
        "frame",
        "grconvertX",
        "grconvertY",
        "grid",
        "hist",
        "hist.default",
        "identify",
        "image",
        "image.default",
        "layout",
        "layout.show",
        "lcm",
        "legend",
        "lines",
        "lines.default",
        "locator",
        "matlines",
        "matplot",
        "matpoints",
        "mosaicplot",
        "mtext",
        "pairs",
        "pairs.default",
        "panel.smooth",
        "par",
        "persp",
        "pie",
        "plot",
        "plot.default",
        "plot.design",
        "plot.function",
        "plot.new",
        "plot.window",
        "plot.xy",
        "points",
        "points.default",
        "polygon",
        "polypath",
        "rasterImage",
        "rect",
        "rug",
        "screen",
        "segments",
        "smoothScatter",
        "spineplot",
        "split.screen",
        "stars",
        "stem",
        "strheight",
        "stripchart",
        "strwidth",
        "sunflowerplot",
        "symbols",
        "text",
        "text.default",
        "title",
        "xinch",
        "xspline",
        "xyinch",
        "yinch",
        "acf",
        "acf2AR",
        "add.scope",
        "add1",
        "addmargins",
        "aggregate",
        "aggregate.data.frame",
        "aggregate.ts",
        "AIC",
        "alias",
        "anova",
        "ansari.test",
        "aov",
        "approx",
        "approxfun",
        "ar",
        "ar.burg",
        "ar.mle",
        "ar.ols",
        "ar.yw",
        "arima",
        "arima.sim",
        "arima0",
        "arima0.diag",
        "ARMAacf",
        "ARMAtoMA",
        "as.dendrogram",
        "as.dist",
        "as.formula",
        "as.hclust",
        "as.stepfun",
        "as.ts",
        "asOneSidedFormula",
        "ave",
        "bandwidth.kernel",
        "bartlett.test",
        "BIC",
        "binom.test",
        "binomial",
        "biplot",
        "Box.test",
        "bw.bcv",
        "bw.nrd",
        "bw.nrd0",
        "bw.SJ",
        "bw.ucv",
        "C",
        "cancor",
        "case.names",
        "ccf",
        "chisq.test",
        "cmdscale",
        "coef",
        "coefficients",
        "complete.cases",
        "confint",
        "confint.default",
        "confint.lm",
        "constrOptim",
        "contr.helmert",
        "contr.poly",
        "contr.SAS",
        "contr.sum",
        "contr.treatment",
        "contrasts",
        "contrasts<-",
        "convolve",
        "cooks.distance",
        "cophenetic",
        "cor",
        "cor.test",
        "cov",
        "cov.wt",
        "cov2cor",
        "covratio",
        "cpgram",
        "cutree",
        "cycle",
        "D",
        "dbeta",
        "dbinom",
        "dcauchy",
        "dchisq",
        "decompose",
        "delete.response",
        "deltat",
        "dendrapply",
        "density",
        "density.default",
        "deriv",
        "deriv3",
        "deviance",
        "dexp",
        "df",
        "df.kernel",
        "df.residual",
        "DF2formula",
        "dfbeta",
        "dfbetas",
        "dffits",
        "dgamma",
        "dgeom",
        "dhyper",
        "diffinv",
        "dist",
        "dlnorm",
        "dlogis",
        "dmultinom",
        "dnbinom",
        "dnorm",
        "dpois",
        "drop.scope",
        "drop.terms",
        "drop1",
        "dsignrank",
        "dt",
        "dummy.coef",
        "dummy.coef.lm",
        "dunif",
        "dweibull",
        "dwilcox",
        "ecdf",
        "eff.aovlist",
        "effects",
        "embed",
        "end",
        "estVar",
        "expand.model.frame",
        "extractAIC",
        "factanal",
        "factor.scope",
        "family",
        "fft",
        "filter",
        "fisher.test",
        "fitted",
        "fitted.values",
        "fivenum",
        "fligner.test",
        "formula",
        "free1way",
        "frequency",
        "friedman.test",
        "ftable",
        "Gamma",
        "gaussian",
        "get_all_vars",
        "getCall",
        "getInitial",
        "glm",
        "glm.control",
        "glm.fit",
        "hasTsp",
        "hat",
        "hatvalues",
        "hclust",
        "heatmap",
        "HoltWinters",
        "influence",
        "influence.measures",
        "integrate",
        "interaction.plot",
        "inverse.gaussian",
        "IQR",
        "is.empty.model",
        "is.leaf",
        "is.mts",
        "is.stepfun",
        "is.ts",
        "is.tskernel",
        "isoreg",
        "KalmanForecast",
        "KalmanLike",
        "KalmanRun",
        "KalmanSmooth",
        "kernapply",
        "kernel",
        "kmeans",
        "knots",
        "kruskal.test",
        "ks.test",
        "ksmooth",
        "lag",
        "lag.plot",
        "line",
        "lm",
        "lm.fit",
        "lm.influence",
        "lm.wfit",
        "loadings",
        "loess",
        "loess.control",
        "loess.smooth",
        "logLik",
        "loglin",
        "lowess",
        "ls.diag",
        "ls.print",
        "lsfit",
        "mad",
        "mahalanobis",
        "make.link",
        "makeARIMA",
        "makepredictcall",
        "manova",
        "mantelhaen.test",
        "mauchly.test",
        "mcnemar.test",
        "median",
        "median.default",
        "medpolish",
        "model.extract",
        "model.frame",
        "model.frame.default",
        "model.matrix",
        "model.matrix.default",
        "model.matrix.lm",
        "model.offset",
        "model.response",
        "model.tables",
        "model.weights",
        "monthplot",
        "mood.test",
        "mvfft",
        "na.action",
        "na.contiguous",
        "na.exclude",
        "na.fail",
        "na.omit",
        "na.pass",
        "napredict",
        "naprint",
        "naresid",
        "nextn",
        "nlm",
        "nlminb",
        "nls",
        "nls.control",
        "NLSstAsymptotic",
        "NLSstClosestX",
        "NLSstLfAsymptote",
        "NLSstRtAsymptote",
        "nobs",
        "numericDeriv",
        "offset",
        "oneway.test",
        "optim",
        "optimHess",
        "optimise",
        "optimize",
        "order.dendrogram",
        "p.adjust",
        "p.adjust.methods",
        "pacf",
        "Pair",
        "pairwise.prop.test",
        "pairwise.t.test",
        "pairwise.table",
        "pairwise.wilcox.test",
        "pbeta",
        "pbinom",
        "pbirthday",
        "pcauchy",
        "pchisq",
        "pexp",
        "pf",
        "pgamma",
        "pgeom",
        "phyper",
        "plclust",
        "plnorm",
        "plogis",
        "plot.ecdf",
        "plot.spec.coherency",
        "plot.spec.phase",
        "plot.stepfun",
        "plot.ts",
        "pnbinom",
        "pnorm",
        "poisson",
        "poisson.test",
        "poly",
        "polym",
        "power",
        "power.anova.test",
        "power.free1way.test",
        "power.prop.test",
        "power.t.test",
        "PP.test",
        "ppoints",
        "ppois",
        "ppplot",
        "ppr",
        "prcomp",
        "predict",
        "predict.glm",
        "predict.lm",
        "preplot",
        "princomp",
        "printCoefmat",
        "profile",
        "proj",
        "promax",
        "prop.test",
        "prop.trend.test",
        "psignrank",
        "psmirnov",
        "pt",
        "ptukey",
        "punif",
        "pweibull",
        "pwilcox",
        "qbeta",
        "qbinom",
        "qbirthday",
        "qcauchy",
        "qchisq",
        "qexp",
        "qf",
        "qgamma",
        "qgeom",
        "qhyper",
        "qlnorm",
        "qlogis",
        "qnbinom",
        "qnorm",
        "qpois",
        "qqline",
        "qqnorm",
        "qqplot",
        "qr.influence",
        "qsignrank",
        "qsmirnov",
        "qt",
        "qtukey",
        "quade.test",
        "quantile",
        "quasi",
        "quasibinomial",
        "quasipoisson",
        "qunif",
        "qweibull",
        "qwilcox",
        "r2dtable",
        "rbeta",
        "rbinom",
        "rcauchy",
        "rchisq",
        "read.ftable",
        "rect.hclust",
        "reformulate",
        "relevel",
        "reorder",
        "replications",
        "reshape",
        "resid",
        "residuals",
        "residuals.glm",
        "residuals.lm",
        "rexp",
        "rf",
        "rfree1way",
        "rgamma",
        "rgeom",
        "rhyper",
        "rlnorm",
        "rlogis",
        "rmultinom",
        "rnbinom",
        "rnorm",
        "rpois",
        "rsignrank",
        "rsmirnov",
        "rstandard",
        "rstudent",
        "rt",
        "runif",
        "runmed",
        "rweibull",
        "rwilcox",
        "rWishart",
        "scatter.smooth",
        "screeplot",
        "sd",
        "se.contrast",
        "selfStart",
        "setNames",
        "shapiro.test",
        "sigma",
        "simulate",
        "smooth",
        "smooth.spline",
        "smoothEnds",
        "sortedXyData",
        "spec.ar",
        "spec.pgram",
        "spec.taper",
        "spectrum",
        "spline",
        "splinefun",
        "splinefunH",
        "SSasymp",
        "SSasympOff",
        "SSasympOrig",
        "SSbiexp",
        "SSD",
        "SSfol",
        "SSfpl",
        "SSgompertz",
        "SSlogis",
        "SSmicmen",
        "SSweibull",
        "start",
        "stat.anova",
        "step",
        "stepfun",
        "stl",
        "StructTS",
        "summary.aov",
        "summary.glm",
        "summary.lm",
        "summary.manova",
        "summary.stepfun",
        "supsmu",
        "symnum",
        "t.test",
        "termplot",
        "terms",
        "terms.formula",
        "time",
        "toeplitz",
        "toeplitz2",
        "ts",
        "ts.intersect",
        "ts.plot",
        "ts.union",
        "tsdiag",
        "tsp",
        "tsp<-",
        "tsSmooth",
        "TukeyHSD",
        "uniroot",
        "update",
        "update.default",
        "update.formula",
        "var",
        "var.test",
        "variable.names",
        "varimax",
        "vcov",
        "weighted.mean",
        "weighted.residuals",
        "weights",
        "wilcox.test",
        "window",
        "window<-",
        "write.ftable",
        "xtabs",
        "addNextMethod",
        "allNames",
        "Arith",
        "as",
        "as<-",
        "asMethodDefinition",
        "assignClassDef",
        "assignMethodsMetaData",
        "balanceMethodsList",
        "body<-",
        "cacheGenericsMetaData",
        "cacheMetaData",
        "cacheMethod",
        "callGeneric",
        "callNextMethod",
        "canCoerce",
        "cbind2",
        "checkAtAssignment",
        "checkSlotAssignment",
        "classesToAM",
        "classLabel",
        "classMetaName",
        "className",
        "coerce",
        "coerce<-",
        "Compare",
        "completeClassDefinition",
        "completeExtends",
        "completeSubclasses",
        "Complex",
        "conformMethod",
        "defaultDumpName",
        "defaultPrototype",
        "doPrimitiveMethod",
        "dumpMethod",
        "dumpMethods",
        "el",
        "el<-",
        "elNamed",
        "elNamed<-",
        "empty.dump",
        "emptyMethodsList",
        "evalOnLoad",
        "evalqOnLoad",
        "evalSource",
        "existsFunction",
        "existsMethod",
        "extends",
        "externalRefMethod",
        "finalDefaultMethod",
        "findClass",
        "findFunction",
        "findMethod",
        "findMethods",
        "findMethodSignatures",
        "findUnique",
        "fixPre1.8",
        "formalArgs",
        "functionBody",
        "functionBody<-",
        "generic.skeleton",
        "getAllSuperClasses",
        "getClass",
        "getClassDef",
        "getClasses",
        "getDataPart",
        "getFunction",
        "getGeneric",
        "getGenerics",
        "getGroup",
        "getGroupMembers",
        "getLoadActions",
        "getMethod",
        "getMethods",
        "getMethodsForDispatch",
        "getMethodsMetaData",
        "getPackageName",
        "getRefClass",
        "getSlots",
        "getValidity",
        "hasArg",
        "hasLoadAction",
        "hasMethod",
        "hasMethods",
        "implicitGeneric",
        "inheritedSlotNames",
        "initFieldArgs",
        "initialize",
        "initRefFields",
        "insertClassMethods",
        "insertMethod",
        "insertSource",
        "is",
        "isClass",
        "isClassDef",
        "isClassUnion",
        "isGeneric",
        "isGrammarSymbol",
        "isGroup",
        "isRematched",
        "isSealedClass",
        "isSealedMethod",
        "isVirtualClass",
        "isXS3Class",
        "kronecker",
        "languageEl",
        "languageEl<-",
        "listFromMethods",
        "loadMethod",
        "Logic",
        "makeClassRepresentation",
        "makeExtends",
        "makeGeneric",
        "makeMethodsList",
        "makePrototypeFromClassDef",
        "makeStandardGeneric",
        "matchSignature",
        "Math",
        "Math2",
        "matrixOps",
        "mergeMethods",
        "metaNameUndo",
        "method.skeleton",
        "MethodAddCoerce",
        "methodSignatureMatrix",
        "MethodsList",
        "MethodsListSelect",
        "methodsPackageMetaName",
        "missingArg",
        "multipleClasses",
        "new",
        "newBasic",
        "newClassRepresentation",
        "newEmptyObject",
        "Ops",
        "packageSlot",
        "packageSlot<-",
        "possibleExtends",
        "prohibitGeneric",
        "promptClass",
        "promptMethods",
        "prototype",
        "Quote",
        "rbind2",
        "reconcilePropertiesAndPrototype",
        "registerImplicitGenerics",
        "rematchDefinition",
        "removeClass",
        "removeGeneric",
        "removeMethod",
        "removeMethods",
        "representation",
        "requireMethods",
        "resetClass",
        "resetGeneric",
        "S3Class",
        "S3Class<-",
        "S3Part",
        "S3Part<-",
        "sealClass",
        "selectMethod",
        "selectSuperClasses",
        "setAs",
        "setClass",
        "setClassUnion",
        "setDataPart",
        "setGeneric",
        "setGenericImplicit",
        "setGroupGeneric",
        "setIs",
        "setLoadAction",
        "setLoadActions",
        "setMethod",
        "setOldClass",
        "setPackageName",
        "setPrimitiveMethods",
        "setRefClass",
        "setReplaceMethod",
        "setValidity",
        "show",
        "showClass",
        "showDefault",
        "showExtends",
        "showMethods",
        "signature",
        "SignatureMethod",
        "sigToEnv",
        "slot",
        "slot<-",
        "slotNames",
        "slotsFromS3",
        "substituteDirect",
        "substituteFunctionArgs",
        "Summary",
        "superClassDepth",
        "testInheritedMethods",
        "testVirtual",
        "tryNew",
        "unRematchDefinition",
        "validObject",
        "validSlotNames"
    };
