/********************************************************************************
** Form generated from reading UI file 'axisrange.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AXISRANGE_H
#define UI_AXISRANGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AxisRangeControl
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QDoubleSpinBox *minEdit;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QDoubleSpinBox *maxEdit;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AxisRangeControl)
    {
        if (AxisRangeControl->objectName().isEmpty())
            AxisRangeControl->setObjectName("AxisRangeControl");
        AxisRangeControl->resize(400, 300);
        verticalLayout = new QVBoxLayout(AxisRangeControl);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(AxisRangeControl);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        minEdit = new QDoubleSpinBox(AxisRangeControl);
        minEdit->setObjectName("minEdit");
        minEdit->setMinimum(-65536.000000000000000);
        minEdit->setMaximum(65536.000000000000000);

        horizontalLayout->addWidget(minEdit);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(AxisRangeControl);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        maxEdit = new QDoubleSpinBox(AxisRangeControl);
        maxEdit->setObjectName("maxEdit");
        maxEdit->setMinimum(-65536.000000000000000);
        maxEdit->setMaximum(65536.000000000000000);
        maxEdit->setValue(100.000000000000000);

        horizontalLayout_2->addWidget(maxEdit);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(AxisRangeControl);

        QMetaObject::connectSlotsByName(AxisRangeControl);
    } // setupUi

    void retranslateUi(QWidget *AxisRangeControl)
    {
        label->setText(tr2i18n("From:", nullptr));
        label_2->setText(tr2i18n("To:", nullptr));
        (void)AxisRangeControl;
    } // retranslateUi

};

namespace Ui {
    class AxisRangeControl: public Ui_AxisRangeControl {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AXISRANGE_H

