/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "keditlistwidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_QalculateSettingsBase
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab_3;
    QGridLayout *gridLayout;
    QSpinBox *kcfg_base;
    QLabel *label_6;
    QLabel *label_8;
    KUrlRequester *kcfg_Path;
    QLabel *label_9;
    QLabel *label_7;
    QLabel *label;
    QCheckBox *kcfg_useAllPrefixes;
    QLabel *label_5;
    KComboBox *kcfg_minExp;
    QCheckBox *kcfg_indicateInfiniteSeries;
    QSpacerItem *verticalSpacer;
    QLabel *label_19;
    KComboBox *kcfg_fractionFormat;
    QCheckBox *kcfg_negativeExponents;
    QWidget *tab_2;
    QGridLayout *gridLayout_2;
    QLabel *label_2;
    QCheckBox *kcfg_postConversion;
    KComboBox *kcfg_angleUnit;
    QLabel *label_4;
    KComboBox *kcfg_structuring;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_3;
    QWidget *tab;
    QGridLayout *gridLayout_3;
    QLabel *label_10;
    QCheckBox *kcfg_inlinePlot;
    QCheckBox *kcfg_coloredPlot;
    QCheckBox *kcfg_plotGrid;
    QLabel *label_12;
    QCheckBox *kcfg_plotBorder;
    QLabel *label_17;
    QSpinBox *kcfg_plotLineWidth;
    QLabel *label_18;
    QSpinBox *kcfg_plotSteps;
    QLabel *label_13;
    KComboBox *kcfg_plotSmoothing;
    KComboBox *kcfg_plotStyle;
    QLabel *label_16;
    KComboBox *kcfg_plotLegend;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_15;
    QLabel *label_11;
    QLabel *label_14;
    QWidget *tabAutoran;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayoutScripts;
    KEditListWidget *kcfg_autorunScripts;
    QWidget *tabDocumentation;

    void setupUi(QWidget *QalculateSettingsBase)
    {
        if (QalculateSettingsBase->objectName().isEmpty())
            QalculateSettingsBase->setObjectName("QalculateSettingsBase");
        QalculateSettingsBase->resize(424, 364);
        verticalLayout = new QVBoxLayout(QalculateSettingsBase);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, 6, 6, 6);
        tabWidget = new QTabWidget(QalculateSettingsBase);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(false);
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout = new QGridLayout(tab_3);
        gridLayout->setObjectName("gridLayout");
        kcfg_base = new QSpinBox(tab_3);
        kcfg_base->setObjectName("kcfg_base");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_base->sizePolicy().hasHeightForWidth());
        kcfg_base->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_base, 1, 1, 1, 1);

        label_6 = new QLabel(tab_3);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_6, 4, 0, 1, 1);

        label_8 = new QLabel(tab_3);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_8, 6, 0, 1, 1);

        kcfg_Path = new KUrlRequester(tab_3);
        kcfg_Path->setObjectName("kcfg_Path");

        gridLayout->addWidget(kcfg_Path, 0, 1, 1, 1);

        label_9 = new QLabel(tab_3);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_9, 3, 0, 1, 1);

        label_7 = new QLabel(tab_3);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_7, 5, 0, 1, 1);

        label = new QLabel(tab_3);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        kcfg_useAllPrefixes = new QCheckBox(tab_3);
        kcfg_useAllPrefixes->setObjectName("kcfg_useAllPrefixes");

        gridLayout->addWidget(kcfg_useAllPrefixes, 5, 1, 1, 1);

        label_5 = new QLabel(tab_3);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        kcfg_minExp = new KComboBox(tab_3);
        kcfg_minExp->addItem(QString());
        kcfg_minExp->addItem(QString());
        kcfg_minExp->addItem(QString());
        kcfg_minExp->addItem(QString());
        kcfg_minExp->setObjectName("kcfg_minExp");

        gridLayout->addWidget(kcfg_minExp, 3, 1, 1, 1);

        kcfg_indicateInfiniteSeries = new QCheckBox(tab_3);
        kcfg_indicateInfiniteSeries->setObjectName("kcfg_indicateInfiniteSeries");

        gridLayout->addWidget(kcfg_indicateInfiniteSeries, 4, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 102, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 1);

        label_19 = new QLabel(tab_3);
        label_19->setObjectName("label_19");

        gridLayout->addWidget(label_19, 0, 0, 1, 1);

        kcfg_fractionFormat = new KComboBox(tab_3);
        kcfg_fractionFormat->addItem(QString());
        kcfg_fractionFormat->addItem(QString());
        kcfg_fractionFormat->addItem(QString());
        kcfg_fractionFormat->addItem(QString());
        kcfg_fractionFormat->setObjectName("kcfg_fractionFormat");

        gridLayout->addWidget(kcfg_fractionFormat, 2, 1, 1, 1);

        kcfg_negativeExponents = new QCheckBox(tab_3);
        kcfg_negativeExponents->setObjectName("kcfg_negativeExponents");

        gridLayout->addWidget(kcfg_negativeExponents, 6, 1, 1, 1);

        tabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_2 = new QGridLayout(tab_2);
        gridLayout_2->setObjectName("gridLayout_2");
        label_2 = new QLabel(tab_2);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_2, 0, 0, 1, 2);

        kcfg_postConversion = new QCheckBox(tab_2);
        kcfg_postConversion->setObjectName("kcfg_postConversion");
        sizePolicy.setHeightForWidth(kcfg_postConversion->sizePolicy().hasHeightForWidth());
        kcfg_postConversion->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(kcfg_postConversion, 0, 2, 1, 1);

        kcfg_angleUnit = new KComboBox(tab_2);
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->addItem(QString());
        kcfg_angleUnit->setObjectName("kcfg_angleUnit");

        gridLayout_2->addWidget(kcfg_angleUnit, 1, 2, 1, 1);

        label_4 = new QLabel(tab_2);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_4, 2, 0, 1, 2);

        kcfg_structuring = new KComboBox(tab_2);
        kcfg_structuring->addItem(QString());
        kcfg_structuring->addItem(QString());
        kcfg_structuring->addItem(QString());
        kcfg_structuring->setObjectName("kcfg_structuring");

        gridLayout_2->addWidget(kcfg_structuring, 2, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 185, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 3, 0, 1, 1);

        label_3 = new QLabel(tab_2);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_3, 1, 0, 1, 2);

        tabWidget->addTab(tab_2, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_3 = new QGridLayout(tab);
        gridLayout_3->setObjectName("gridLayout_3");
        label_10 = new QLabel(tab);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_10, 0, 0, 1, 2);

        kcfg_inlinePlot = new QCheckBox(tab);
        kcfg_inlinePlot->setObjectName("kcfg_inlinePlot");
        sizePolicy.setHeightForWidth(kcfg_inlinePlot->sizePolicy().hasHeightForWidth());
        kcfg_inlinePlot->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(kcfg_inlinePlot, 0, 2, 1, 1);

        kcfg_coloredPlot = new QCheckBox(tab);
        kcfg_coloredPlot->setObjectName("kcfg_coloredPlot");

        gridLayout_3->addWidget(kcfg_coloredPlot, 1, 2, 1, 1);

        kcfg_plotGrid = new QCheckBox(tab);
        kcfg_plotGrid->setObjectName("kcfg_plotGrid");

        gridLayout_3->addWidget(kcfg_plotGrid, 2, 2, 1, 1);

        label_12 = new QLabel(tab);
        label_12->setObjectName("label_12");
        label_12->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_12, 3, 0, 1, 2);

        kcfg_plotBorder = new QCheckBox(tab);
        kcfg_plotBorder->setObjectName("kcfg_plotBorder");

        gridLayout_3->addWidget(kcfg_plotBorder, 3, 2, 1, 1);

        label_17 = new QLabel(tab);
        label_17->setObjectName("label_17");
        label_17->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_17, 4, 0, 1, 2);

        kcfg_plotLineWidth = new QSpinBox(tab);
        kcfg_plotLineWidth->setObjectName("kcfg_plotLineWidth");
        kcfg_plotLineWidth->setMinimum(1);

        gridLayout_3->addWidget(kcfg_plotLineWidth, 4, 2, 1, 1);

        label_18 = new QLabel(tab);
        label_18->setObjectName("label_18");
        label_18->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_18, 5, 0, 1, 2);

        kcfg_plotSteps = new QSpinBox(tab);
        kcfg_plotSteps->setObjectName("kcfg_plotSteps");
        kcfg_plotSteps->setMinimum(1);

        gridLayout_3->addWidget(kcfg_plotSteps, 5, 2, 1, 1);

        label_13 = new QLabel(tab);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_13, 6, 0, 1, 2);

        kcfg_plotSmoothing = new KComboBox(tab);
        kcfg_plotSmoothing->addItem(QString());
        kcfg_plotSmoothing->addItem(QString());
        kcfg_plotSmoothing->addItem(QString());
        kcfg_plotSmoothing->addItem(QString());
        kcfg_plotSmoothing->addItem(QString());
        kcfg_plotSmoothing->setObjectName("kcfg_plotSmoothing");

        gridLayout_3->addWidget(kcfg_plotSmoothing, 6, 2, 1, 1);

        kcfg_plotStyle = new KComboBox(tab);
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->addItem(QString());
        kcfg_plotStyle->setObjectName("kcfg_plotStyle");

        gridLayout_3->addWidget(kcfg_plotStyle, 7, 2, 1, 1);

        label_16 = new QLabel(tab);
        label_16->setObjectName("label_16");
        label_16->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_16, 8, 0, 1, 2);

        kcfg_plotLegend = new KComboBox(tab);
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->addItem(QString());
        kcfg_plotLegend->setObjectName("kcfg_plotLegend");

        gridLayout_3->addWidget(kcfg_plotLegend, 8, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 22, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_3, 9, 0, 1, 1);

        label_15 = new QLabel(tab);
        label_15->setObjectName("label_15");
        label_15->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_15, 1, 0, 1, 2);

        label_11 = new QLabel(tab);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_11, 2, 0, 1, 2);

        label_14 = new QLabel(tab);
        label_14->setObjectName("label_14");
        label_14->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_14, 7, 0, 1, 2);

        tabWidget->addTab(tab, QString());
        tabAutoran = new QWidget();
        tabAutoran->setObjectName("tabAutoran");
        verticalLayout_5 = new QVBoxLayout(tabAutoran);
        verticalLayout_5->setObjectName("verticalLayout_5");
        groupBox = new QGroupBox(tabAutoran);
        groupBox->setObjectName("groupBox");
        verticalLayoutScripts = new QVBoxLayout(groupBox);
        verticalLayoutScripts->setObjectName("verticalLayoutScripts");
        kcfg_autorunScripts = new KEditListWidget(groupBox);
        kcfg_autorunScripts->setObjectName("kcfg_autorunScripts");

        verticalLayoutScripts->addWidget(kcfg_autorunScripts);


        verticalLayout_5->addWidget(groupBox);

        tabWidget->addTab(tabAutoran, QString());
        tabDocumentation = new QWidget();
        tabDocumentation->setObjectName("tabDocumentation");
        tabWidget->addTab(tabDocumentation, QString());

        verticalLayout->addWidget(tabWidget);


        retranslateUi(QalculateSettingsBase);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(QalculateSettingsBase);
    } // setupUi

    void retranslateUi(QWidget *QalculateSettingsBase)
    {
        label_6->setText(tr2i18n("Indicate infinite series:", nullptr));
        label_8->setText(tr2i18n("Use negative exponents:", nullptr));
        label_9->setText(tr2i18n("Numerical display:", nullptr));
        label_7->setText(tr2i18n("Use all SI prefixes:", nullptr));
        label->setText(tr2i18n("Number base:", nullptr));
        kcfg_useAllPrefixes->setText(tr2i18n("Enabled", nullptr));
        label_5->setText(tr2i18n("Fraction format:", nullptr));
        kcfg_minExp->setItemText(0, tr2i18n("None", nullptr));
        kcfg_minExp->setItemText(1, tr2i18n("Pure", nullptr));
        kcfg_minExp->setItemText(2, tr2i18n("Scientific", nullptr));
        kcfg_minExp->setItemText(3, tr2i18n("Precision", nullptr));

        kcfg_indicateInfiniteSeries->setText(tr2i18n("Enabled", nullptr));
        label_19->setText(tr2i18n("Executable:", nullptr));
        kcfg_fractionFormat->setItemText(0, tr2i18n("Decimal", nullptr));
        kcfg_fractionFormat->setItemText(1, tr2i18n("Exact", nullptr));
        kcfg_fractionFormat->setItemText(2, tr2i18n("Fractional", nullptr));
        kcfg_fractionFormat->setItemText(3, tr2i18n("Combined", nullptr));

        kcfg_negativeExponents->setText(tr2i18n("Enabled", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("General", nullptr));
        label_2->setText(tr2i18n("Convert to best SI units:", nullptr));
        kcfg_postConversion->setText(tr2i18n("Enabled", nullptr));
        kcfg_angleUnit->setItemText(0, tr2i18n("None", nullptr));
        kcfg_angleUnit->setItemText(1, tr2i18n("Radians", nullptr));
        kcfg_angleUnit->setItemText(2, tr2i18n("Degrees", nullptr));
        kcfg_angleUnit->setItemText(3, tr2i18n("Gradians", nullptr));

        label_4->setText(tr2i18n("Structuring Mode:", nullptr));
        kcfg_structuring->setItemText(0, tr2i18n("None", nullptr));
        kcfg_structuring->setItemText(1, tr2i18n("Simplify", nullptr));
        kcfg_structuring->setItemText(2, tr2i18n("Factorize", nullptr));

        label_3->setText(tr2i18n("Angle unit:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Evaluate", nullptr));
        label_10->setText(tr2i18n("Display plots inline:", nullptr));
        kcfg_inlinePlot->setText(tr2i18n("Enabled", nullptr));
        kcfg_coloredPlot->setText(tr2i18n("Enabled", nullptr));
        kcfg_plotGrid->setText(tr2i18n("Enabled", nullptr));
        label_12->setText(tr2i18n("Show full borders:", nullptr));
        kcfg_plotBorder->setText(tr2i18n("Enabled", nullptr));
        label_17->setText(tr2i18n("Width of lines:", nullptr));
        label_18->setText(tr2i18n("Sampling rate:", nullptr));
        label_13->setText(tr2i18n("Smoothing Mode:", nullptr));
        kcfg_plotSmoothing->setItemText(0, tr2i18n("None", nullptr));
        kcfg_plotSmoothing->setItemText(1, tr2i18n("Monotonic", nullptr));
        kcfg_plotSmoothing->setItemText(2, tr2i18n("Natural cubic Splines", nullptr));
        kcfg_plotSmoothing->setItemText(3, tr2i18n("Bezier", nullptr));
        kcfg_plotSmoothing->setItemText(4, tr2i18n("Bezier (monotonic)", nullptr));

        kcfg_plotStyle->setItemText(0, tr2i18n("Lines", nullptr));
        kcfg_plotStyle->setItemText(1, tr2i18n("Points", nullptr));
        kcfg_plotStyle->setItemText(2, tr2i18n("Points and Lines", nullptr));
        kcfg_plotStyle->setItemText(3, tr2i18n("Boxes", nullptr));
        kcfg_plotStyle->setItemText(4, tr2i18n("Histogram", nullptr));
        kcfg_plotStyle->setItemText(5, tr2i18n("Steps", "Plot Style"));
        kcfg_plotStyle->setItemText(6, tr2i18n("Candlesticks", nullptr));
        kcfg_plotStyle->setItemText(7, tr2i18n("Dots", nullptr));

        label_16->setText(tr2i18n("Legend Position:", nullptr));
        kcfg_plotLegend->setItemText(0, tr2i18n("Hide legend", nullptr));
        kcfg_plotLegend->setItemText(1, tr2i18n("Top-left", nullptr));
        kcfg_plotLegend->setItemText(2, tr2i18n("Top-right", nullptr));
        kcfg_plotLegend->setItemText(3, tr2i18n("Bottom-left", nullptr));
        kcfg_plotLegend->setItemText(4, tr2i18n("Bottom-right", nullptr));
        kcfg_plotLegend->setItemText(5, tr2i18n("Below", nullptr));
        kcfg_plotLegend->setItemText(6, tr2i18n("Outside", nullptr));

        label_15->setText(tr2i18n("Colored Plots:", nullptr));
        label_11->setText(tr2i18n("Show grid:", nullptr));
        label_14->setText(tr2i18n("Plot Style:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Plotting", nullptr));
        groupBox->setTitle(tr2i18n("Commands to autorun", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAutoran), tr2i18n("Autorun", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDocumentation), tr2i18n("Documentation", nullptr));
        (void)QalculateSettingsBase;
    } // retranslateUi

};

namespace Ui {
    class QalculateSettingsBase: public Ui_QalculateSettingsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

