// This file is generated by kconfig_compiler_kf6 from cantor.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <cantor_config_export.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <QApplication>

class CANTOR_CONFIG_EXPORT Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Set The Backend that is used by default
    */
    static
    void setDefaultBackend( const QString & v )
    {
      if (!self()->isDefaultBackendImmutable())
        self()->mDefaultBackend = v;
    }

    /**
      Get The Backend that is used by default
    */
    static
    QString defaultBackend()
    {
      return self()->mDefaultBackend;
    }

    /**
      Is The Backend that is used by default Immutable
    */
    static
    bool isDefaultBackendImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DefaultBackend" ) );
    }

    /**
      Set Default editor color theme
    */
    static
    void setDefaultTheme( const QString & v )
    {
      if (!self()->isDefaultThemeImmutable())
        self()->mDefaultTheme = v;
    }

    /**
      Get Default editor color theme
    */
    static
    QString defaultTheme()
    {
      return self()->mDefaultTheme;
    }

    /**
      Is Default editor color theme Immutable
    */
    static
    bool isDefaultThemeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DefaultTheme" ) );
    }

    /**
      Set Do Typesetting by default
    */
    static
    void setTypesetDefault( bool v )
    {
      if (!self()->isTypesetDefaultImmutable())
        self()->mTypesetDefault = v;
    }

    /**
      Get Do Typesetting by default
    */
    static
    bool typesetDefault()
    {
      return self()->mTypesetDefault;
    }

    /**
      Is Do Typesetting by default Immutable
    */
    static
    bool isTypesetDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TypesetDefault" ) );
    }

    /**
      Set Do Syntax Highlighting by default
    */
    static
    void setHighlightDefault( bool v )
    {
      if (!self()->isHighlightDefaultImmutable())
        self()->mHighlightDefault = v;
    }

    /**
      Get Do Syntax Highlighting by default
    */
    static
    bool highlightDefault()
    {
      return self()->mHighlightDefault;
    }

    /**
      Is Do Syntax Highlighting by default Immutable
    */
    static
    bool isHighlightDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "HighlightDefault" ) );
    }

    /**
      Set Enable Completions by default
    */
    static
    void setCompletionDefault( bool v )
    {
      if (!self()->isCompletionDefaultImmutable())
        self()->mCompletionDefault = v;
    }

    /**
      Get Enable Completions by default
    */
    static
    bool completionDefault()
    {
      return self()->mCompletionDefault;
    }

    /**
      Is Enable Completions by default Immutable
    */
    static
    bool isCompletionDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "CompletionDefault" ) );
    }

    /**
      Set Enable Numbering of Expressions by default
    */
    static
    void setExpressionNumberingDefault( bool v )
    {
      if (!self()->isExpressionNumberingDefaultImmutable())
        self()->mExpressionNumberingDefault = v;
    }

    /**
      Get Enable Numbering of Expressions by default
    */
    static
    bool expressionNumberingDefault()
    {
      return self()->mExpressionNumberingDefault;
    }

    /**
      Is Enable Numbering of Expressions by default Immutable
    */
    static
    bool isExpressionNumberingDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ExpressionNumberingDefault" ) );
    }

    /**
      Set Animate changes in the Worksheet by default
    */
    static
    void setAnimationDefault( bool v )
    {
      if (!self()->isAnimationDefaultImmutable())
        self()->mAnimationDefault = v;
    }

    /**
      Get Animate changes in the Worksheet by default
    */
    static
    bool animationDefault()
    {
      return self()->mAnimationDefault;
    }

    /**
      Is Animate changes in the Worksheet by default Immutable
    */
    static
    bool isAnimationDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AnimationDefault" ) );
    }

    /**
      Set Enable rendering math expressions inside $$..$$ in Text and Markdown entries by default (needs pdflatex installed)
    */
    static
    void setEmbeddedMathDefault( bool v )
    {
      if (!self()->isEmbeddedMathDefaultImmutable())
        self()->mEmbeddedMathDefault = v;
    }

    /**
      Get Enable rendering math expressions inside $$..$$ in Text and Markdown entries by default (needs pdflatex installed)
    */
    static
    bool embeddedMathDefault()
    {
      return self()->mEmbeddedMathDefault;
    }

    /**
      Is Enable rendering math expressions inside $$..$$ in Text and Markdown entries by default (needs pdflatex installed) Immutable
    */
    static
    bool isEmbeddedMathDefaultImmutable()
    {
      return self()->isImmutable( QStringLiteral( "EmbeddedMathDefault" ) );
    }

    /**
      Set Ask for confirmation when deleting an entry
    */
    static
    void setWarnAboutEntryDelete( bool v )
    {
      if (!self()->isWarnAboutEntryDeleteImmutable())
        self()->mWarnAboutEntryDelete = v;
    }

    /**
      Get Ask for confirmation when deleting an entry
    */
    static
    bool warnAboutEntryDelete()
    {
      return self()->mWarnAboutEntryDelete;
    }

    /**
      Is Ask for confirmation when deleting an entry Immutable
    */
    static
    bool isWarnAboutEntryDeleteImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WarnAboutEntryDelete" ) );
    }

    /**
      Set Automatically reevaluate the entries below the current
    */
    static
    void setAutoEval( bool v )
    {
      if (!self()->isAutoEvalImmutable())
        self()->mAutoEval = v;
    }

    /**
      Get Automatically reevaluate the entries below the current
    */
    static
    bool autoEval()
    {
      return self()->mAutoEval;
    }

    /**
      Is Automatically reevaluate the entries below the current Immutable
    */
    static
    bool isAutoEvalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoEval" ) );
    }

    /**
      Set Ask for confirmation when restarting the backend
    */
    static
    void setWarnAboutSessionRestart( bool v )
    {
      if (!self()->isWarnAboutSessionRestartImmutable())
        self()->mWarnAboutSessionRestart = v;
    }

    /**
      Get Ask for confirmation when restarting the backend
    */
    static
    bool warnAboutSessionRestart()
    {
      return self()->mWarnAboutSessionRestart;
    }

    /**
      Is Ask for confirmation when restarting the backend Immutable
    */
    static
    bool isWarnAboutSessionRestartImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WarnAboutSessionRestart" ) );
    }

    /**
      Set Save rich text formatting of TextEntry, when save Worksheet in Jupyter notebook format
    */
    static
    void setStoreTextEntryFormatting( bool v )
    {
      if (!self()->isStoreTextEntryFormattingImmutable())
        self()->mStoreTextEntryFormatting = v;
    }

    /**
      Get Save rich text formatting of TextEntry, when save Worksheet in Jupyter notebook format
    */
    static
    bool storeTextEntryFormatting()
    {
      return self()->mStoreTextEntryFormatting;
    }

    /**
      Is Save rich text formatting of TextEntry, when save Worksheet in Jupyter notebook format Immutable
    */
    static
    bool isStoreTextEntryFormattingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "StoreTextEntryFormatting" ) );
    }

    /**
      Set Use old style Cantor entries placement style
    */
    static
    void setUseOldCantorEntriesIndent( bool v )
    {
      if (!self()->isUseOldCantorEntriesIndentImmutable())
        self()->mUseOldCantorEntriesIndent = v;
    }

    /**
      Get Use old style Cantor entries placement style
    */
    static
    bool useOldCantorEntriesIndent()
    {
      return self()->mUseOldCantorEntriesIndent;
    }

    /**
      Is Use old style Cantor entries placement style Immutable
    */
    static
    bool isUseOldCantorEntriesIndentImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseOldCantorEntriesIndent" ) );
    }

    /**
      Set Show embedded math render error
    */
    static
    void setShowMathRenderError( bool v )
    {
      if (!self()->isShowMathRenderErrorImmutable())
        self()->mShowMathRenderError = v;
    }

    /**
      Get Show embedded math render error
    */
    static
    bool showMathRenderError()
    {
      return self()->mShowMathRenderError;
    }

    /**
      Is Show embedded math render error Immutable
    */
    static
    bool isShowMathRenderErrorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowMathRenderError" ) );
    }

    /**
      Set Limit of visible lines for text result
    */
    static
    void setVisibleLinesLimit( int v )
    {
      if (!self()->isVisibleLinesLimitImmutable())
        self()->mVisibleLinesLimit = v;
    }

    /**
      Get Limit of visible lines for text result
    */
    static
    int visibleLinesLimit()
    {
      return self()->mVisibleLinesLimit;
    }

    /**
      Is Limit of visible lines for text result Immutable
    */
    static
    bool isVisibleLinesLimitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "VisibleLinesLimit" ) );
    }

    /**
      Set Hierarchy font for chapter
    */
    static
    void setChapterFontFamily( const QFont & v )
    {
      if (!self()->isChapterFontFamilyImmutable())
        self()->mChapterFontFamily = v;
    }

    /**
      Get Hierarchy font for chapter
    */
    static
    QFont chapterFontFamily()
    {
      return self()->mChapterFontFamily;
    }

    /**
      Is Hierarchy font for chapter Immutable
    */
    static
    bool isChapterFontFamilyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChapterFontFamily" ) );
    }

    /**
      Set Hierarchy font size for chapter
    */
    static
    void setChapterFontSize( int v )
    {
      if (!self()->isChapterFontSizeImmutable())
        self()->mChapterFontSize = v;
    }

    /**
      Get Hierarchy font size for chapter
    */
    static
    int chapterFontSize()
    {
      return self()->mChapterFontSize;
    }

    /**
      Is Hierarchy font size for chapter Immutable
    */
    static
    bool isChapterFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChapterFontSize" ) );
    }

    /**
      Set Hierarchy font italic for chapter
    */
    static
    void setChapterFontItalic( bool v )
    {
      if (!self()->isChapterFontItalicImmutable())
        self()->mChapterFontItalic = v;
    }

    /**
      Get Hierarchy font italic for chapter
    */
    static
    bool chapterFontItalic()
    {
      return self()->mChapterFontItalic;
    }

    /**
      Is Hierarchy font italic for chapter Immutable
    */
    static
    bool isChapterFontItalicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChapterFontItalic" ) );
    }

    /**
      Set Hierarchy font bold for chapter
    */
    static
    void setChapterFontBold( bool v )
    {
      if (!self()->isChapterFontBoldImmutable())
        self()->mChapterFontBold = v;
    }

    /**
      Get Hierarchy font bold for chapter
    */
    static
    bool chapterFontBold()
    {
      return self()->mChapterFontBold;
    }

    /**
      Is Hierarchy font bold for chapter Immutable
    */
    static
    bool isChapterFontBoldImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ChapterFontBold" ) );
    }

    /**
      Set Hierarchy font for subchapter
    */
    static
    void setSubchapterFontFamily( const QFont & v )
    {
      if (!self()->isSubchapterFontFamilyImmutable())
        self()->mSubchapterFontFamily = v;
    }

    /**
      Get Hierarchy font for subchapter
    */
    static
    QFont subchapterFontFamily()
    {
      return self()->mSubchapterFontFamily;
    }

    /**
      Is Hierarchy font for subchapter Immutable
    */
    static
    bool isSubchapterFontFamilyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubchapterFontFamily" ) );
    }

    /**
      Set Hierarchy font size for subchapter
    */
    static
    void setSubchapterFontSize( int v )
    {
      if (!self()->isSubchapterFontSizeImmutable())
        self()->mSubchapterFontSize = v;
    }

    /**
      Get Hierarchy font size for subchapter
    */
    static
    int subchapterFontSize()
    {
      return self()->mSubchapterFontSize;
    }

    /**
      Is Hierarchy font size for subchapter Immutable
    */
    static
    bool isSubchapterFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubchapterFontSize" ) );
    }

    /**
      Set Hierarchy font italic for subchapter
    */
    static
    void setSubchapterFontItalic( bool v )
    {
      if (!self()->isSubchapterFontItalicImmutable())
        self()->mSubchapterFontItalic = v;
    }

    /**
      Get Hierarchy font italic for subchapter
    */
    static
    bool subchapterFontItalic()
    {
      return self()->mSubchapterFontItalic;
    }

    /**
      Is Hierarchy font italic for subchapter Immutable
    */
    static
    bool isSubchapterFontItalicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubchapterFontItalic" ) );
    }

    /**
      Set Hierarchy font bold for subchapter
    */
    static
    void setSubchapterFontBold( bool v )
    {
      if (!self()->isSubchapterFontBoldImmutable())
        self()->mSubchapterFontBold = v;
    }

    /**
      Get Hierarchy font bold for subchapter
    */
    static
    bool subchapterFontBold()
    {
      return self()->mSubchapterFontBold;
    }

    /**
      Is Hierarchy font bold for subchapter Immutable
    */
    static
    bool isSubchapterFontBoldImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubchapterFontBold" ) );
    }

    /**
      Set Hierarchy font for section
    */
    static
    void setSectionFontFamily( const QFont & v )
    {
      if (!self()->isSectionFontFamilyImmutable())
        self()->mSectionFontFamily = v;
    }

    /**
      Get Hierarchy font for section
    */
    static
    QFont sectionFontFamily()
    {
      return self()->mSectionFontFamily;
    }

    /**
      Is Hierarchy font for section Immutable
    */
    static
    bool isSectionFontFamilyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SectionFontFamily" ) );
    }

    /**
      Set Hierarchy font for section
    */
    static
    void setSectionFontSize( int v )
    {
      if (!self()->isSectionFontSizeImmutable())
        self()->mSectionFontSize = v;
    }

    /**
      Get Hierarchy font for section
    */
    static
    int sectionFontSize()
    {
      return self()->mSectionFontSize;
    }

    /**
      Is Hierarchy font for section Immutable
    */
    static
    bool isSectionFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SectionFontSize" ) );
    }

    /**
      Set Hierarchy font italic for section
    */
    static
    void setSectionFontItalic( bool v )
    {
      if (!self()->isSectionFontItalicImmutable())
        self()->mSectionFontItalic = v;
    }

    /**
      Get Hierarchy font italic for section
    */
    static
    bool sectionFontItalic()
    {
      return self()->mSectionFontItalic;
    }

    /**
      Is Hierarchy font italic for section Immutable
    */
    static
    bool isSectionFontItalicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SectionFontItalic" ) );
    }

    /**
      Set Hierarchy font bold for section
    */
    static
    void setSectionFontBold( bool v )
    {
      if (!self()->isSectionFontBoldImmutable())
        self()->mSectionFontBold = v;
    }

    /**
      Get Hierarchy font bold for section
    */
    static
    bool sectionFontBold()
    {
      return self()->mSectionFontBold;
    }

    /**
      Is Hierarchy font bold for section Immutable
    */
    static
    bool isSectionFontBoldImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SectionFontBold" ) );
    }

    /**
      Set Hierarchy font for subsection
    */
    static
    void setSubsectionFontFamily( const QFont & v )
    {
      if (!self()->isSubsectionFontFamilyImmutable())
        self()->mSubsectionFontFamily = v;
    }

    /**
      Get Hierarchy font for subsection
    */
    static
    QFont subsectionFontFamily()
    {
      return self()->mSubsectionFontFamily;
    }

    /**
      Is Hierarchy font for subsection Immutable
    */
    static
    bool isSubsectionFontFamilyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubsectionFontFamily" ) );
    }

    /**
      Set Hierarchy font for subsection
    */
    static
    void setSubsectionFontSize( int v )
    {
      if (!self()->isSubsectionFontSizeImmutable())
        self()->mSubsectionFontSize = v;
    }

    /**
      Get Hierarchy font for subsection
    */
    static
    int subsectionFontSize()
    {
      return self()->mSubsectionFontSize;
    }

    /**
      Is Hierarchy font for subsection Immutable
    */
    static
    bool isSubsectionFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubsectionFontSize" ) );
    }

    /**
      Set Hierarchy font italic for subsection
    */
    static
    void setSubsectionFontItalic( bool v )
    {
      if (!self()->isSubsectionFontItalicImmutable())
        self()->mSubsectionFontItalic = v;
    }

    /**
      Get Hierarchy font italic for subsection
    */
    static
    bool subsectionFontItalic()
    {
      return self()->mSubsectionFontItalic;
    }

    /**
      Is Hierarchy font italic for subsection Immutable
    */
    static
    bool isSubsectionFontItalicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubsectionFontItalic" ) );
    }

    /**
      Set Hierarchy font bold for subsection
    */
    static
    void setSubsectionFontBold( bool v )
    {
      if (!self()->isSubsectionFontBoldImmutable())
        self()->mSubsectionFontBold = v;
    }

    /**
      Get Hierarchy font bold for subsection
    */
    static
    bool subsectionFontBold()
    {
      return self()->mSubsectionFontBold;
    }

    /**
      Is Hierarchy font bold for subsection Immutable
    */
    static
    bool isSubsectionFontBoldImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubsectionFontBold" ) );
    }

    /**
      Set Hierarchy font for paragraph
    */
    static
    void setParagraphFontFamily( const QFont & v )
    {
      if (!self()->isParagraphFontFamilyImmutable())
        self()->mParagraphFontFamily = v;
    }

    /**
      Get Hierarchy font for paragraph
    */
    static
    QFont paragraphFontFamily()
    {
      return self()->mParagraphFontFamily;
    }

    /**
      Is Hierarchy font for paragraph Immutable
    */
    static
    bool isParagraphFontFamilyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ParagraphFontFamily" ) );
    }

    /**
      Set Hierarchy font for paragraph
    */
    static
    void setParagraphFontSize( int v )
    {
      if (!self()->isParagraphFontSizeImmutable())
        self()->mParagraphFontSize = v;
    }

    /**
      Get Hierarchy font for paragraph
    */
    static
    int paragraphFontSize()
    {
      return self()->mParagraphFontSize;
    }

    /**
      Is Hierarchy font for paragraph Immutable
    */
    static
    bool isParagraphFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ParagraphFontSize" ) );
    }

    /**
      Set Hierarchy font italic for paragraph
    */
    static
    void setParagraphFontItalic( bool v )
    {
      if (!self()->isParagraphFontItalicImmutable())
        self()->mParagraphFontItalic = v;
    }

    /**
      Get Hierarchy font italic for paragraph
    */
    static
    bool paragraphFontItalic()
    {
      return self()->mParagraphFontItalic;
    }

    /**
      Is Hierarchy font italic for paragraph Immutable
    */
    static
    bool isParagraphFontItalicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ParagraphFontItalic" ) );
    }

    /**
      Set Hierarchy font bold for paragraph
    */
    static
    void setParagraphFontBold( bool v )
    {
      if (!self()->isParagraphFontBoldImmutable())
        self()->mParagraphFontBold = v;
    }

    /**
      Get Hierarchy font bold for paragraph
    */
    static
    bool paragraphFontBold()
    {
      return self()->mParagraphFontBold;
    }

    /**
      Is Hierarchy font bold for paragraph Immutable
    */
    static
    bool isParagraphFontBoldImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ParagraphFontBold" ) );
    }

    /**
      Set Hierarchy font for subparagraph
    */
    static
    void setSubparagraphFontFamily( const QFont & v )
    {
      if (!self()->isSubparagraphFontFamilyImmutable())
        self()->mSubparagraphFontFamily = v;
    }

    /**
      Get Hierarchy font for subparagraph
    */
    static
    QFont subparagraphFontFamily()
    {
      return self()->mSubparagraphFontFamily;
    }

    /**
      Is Hierarchy font for subparagraph Immutable
    */
    static
    bool isSubparagraphFontFamilyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubparagraphFontFamily" ) );
    }

    /**
      Set Hierarchy font for subparagraph
    */
    static
    void setSubparagraphFontSize( int v )
    {
      if (!self()->isSubparagraphFontSizeImmutable())
        self()->mSubparagraphFontSize = v;
    }

    /**
      Get Hierarchy font for subparagraph
    */
    static
    int subparagraphFontSize()
    {
      return self()->mSubparagraphFontSize;
    }

    /**
      Is Hierarchy font for subparagraph Immutable
    */
    static
    bool isSubparagraphFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubparagraphFontSize" ) );
    }

    /**
      Set Hierarchy font italic for subparagraph
    */
    static
    void setSubparagraphFontItalic( bool v )
    {
      if (!self()->isSubparagraphFontItalicImmutable())
        self()->mSubparagraphFontItalic = v;
    }

    /**
      Get Hierarchy font italic for subparagraph
    */
    static
    bool subparagraphFontItalic()
    {
      return self()->mSubparagraphFontItalic;
    }

    /**
      Is Hierarchy font italic for subparagraph Immutable
    */
    static
    bool isSubparagraphFontItalicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubparagraphFontItalic" ) );
    }

    /**
      Set Hierarchy font bold for subparagraph
    */
    static
    void setSubparagraphFontBold( bool v )
    {
      if (!self()->isSubparagraphFontBoldImmutable())
        self()->mSubparagraphFontBold = v;
    }

    /**
      Get Hierarchy font bold for subparagraph
    */
    static
    bool subparagraphFontBold()
    {
      return self()->mSubparagraphFontBold;
    }

    /**
      Is Hierarchy font bold for subparagraph Immutable
    */
    static
    bool isSubparagraphFontBoldImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SubparagraphFontBold" ) );
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // Cantor
    QString mDefaultBackend;
    QString mDefaultTheme;
    bool mTypesetDefault;
    bool mHighlightDefault;
    bool mCompletionDefault;
    bool mExpressionNumberingDefault;
    bool mAnimationDefault;
    bool mEmbeddedMathDefault;
    bool mWarnAboutEntryDelete;
    bool mAutoEval;
    bool mWarnAboutSessionRestart;
    bool mStoreTextEntryFormatting;
    bool mUseOldCantorEntriesIndent;
    bool mShowMathRenderError;
    int mVisibleLinesLimit;
    QFont mChapterFontFamily;
    int mChapterFontSize;
    bool mChapterFontItalic;
    bool mChapterFontBold;
    QFont mSubchapterFontFamily;
    int mSubchapterFontSize;
    bool mSubchapterFontItalic;
    bool mSubchapterFontBold;
    QFont mSectionFontFamily;
    int mSectionFontSize;
    bool mSectionFontItalic;
    bool mSectionFontBold;
    QFont mSubsectionFontFamily;
    int mSubsectionFontSize;
    bool mSubsectionFontItalic;
    bool mSubsectionFontBold;
    QFont mParagraphFontFamily;
    int mParagraphFontSize;
    bool mParagraphFontItalic;
    bool mParagraphFontBold;
    QFont mSubparagraphFontFamily;
    int mSubparagraphFontSize;
    bool mSubparagraphFontItalic;
    bool mSubparagraphFontBold;
};

#endif

