/****************************************************************************
** Meta object code from reading C++ file 'juliaserver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../cantor-26.07.80/src/backends/julia/juliaserver/juliaserver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'juliaserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11JuliaServerE_t {};
} // unnamed namespace

template <> constexpr inline auto JuliaServer::qt_create_metaobjectdata<qt_meta_tag_ZN11JuliaServerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JuliaServer",
        "login",
        "",
        "runJuliaCommand",
        "getOutput",
        "getError",
        "getWasException",
        "parseModules",
        "variableManagement",
        "variablesList",
        "variableValuesList",
        "variableSizesList",
        "variableTypesList",
        "functionsList"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'login'
        QtMocHelpers::SlotData<int()>(1, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'runJuliaCommand'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'getOutput'
        QtMocHelpers::SlotData<QString() const>(4, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'getError'
        QtMocHelpers::SlotData<QString() const>(5, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'getWasException'
        QtMocHelpers::SlotData<bool() const>(6, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'parseModules'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'variablesList'
        QtMocHelpers::SlotData<QStringList()>(9, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'variableValuesList'
        QtMocHelpers::SlotData<QStringList()>(10, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'variableSizesList'
        QtMocHelpers::SlotData<QStringList()>(11, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'variableTypesList'
        QtMocHelpers::SlotData<QStringList()>(12, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'functionsList'
        QtMocHelpers::SlotData<QStringList()>(13, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JuliaServer, qt_meta_tag_ZN11JuliaServerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject JuliaServer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11JuliaServerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11JuliaServerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11JuliaServerE_t>.metaTypes,
    nullptr
} };

void JuliaServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JuliaServer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->login();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->runJuliaCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { QString _r = _t->getOutput();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->getError();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->getWasException();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->parseModules((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: { QStringList _r = _t->variablesList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->variableValuesList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->variableSizesList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QStringList _r = _t->variableTypesList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QStringList _r = _t->functionsList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *JuliaServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JuliaServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11JuliaServerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int JuliaServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
